@@ -1,11 +1,11 @@
     /*
 
-    $Id: kfax.h,v 1.10 1999/01/05 18:39:36 kulow Exp $
+    $Id: kfax.h,v 1.21 2000/02/20 23:08:36 faure Exp $
 
-    Requires the Qt widget libraries, available at no cost at 
+    Requires the Qt widget libraries, available at no cost at
     http://www.troll.no
-       
-    Copyright (C) 1997 Bernd Johannes Wuebben   
+
+    Copyright (C) 1997 Bernd Johannes Wuebben
                        wuebben@math.cornell.edu
 
 
@@ -31,28 +31,27 @@
 #include <qlist.h>
 #include <qstring.h>
 
-#include <qpopmenu.h>
+#include <qpopupmenu.h>
 #include <qmenubar.h>
-#include <qapp.h>
+#include <qapplication.h>
 #include <qkeycode.h>
 #include <qaccel.h>
 #include <qobject.h>
-#include <qmlined.h>
-#include <qradiobt.h>
-#include <qfiledlg.h>
-#include <qchkbox.h>
-#include <qmsgbox.h>
-#include <qgrpbox.h>
+#include <qmultilinedit.h>
+#include <qradiobutton.h>
+#include <qfiledialog.h>
+#include <qcheckbox.h>
+#include <qgroupbox.h>
 #include <qtooltip.h>
-#include <qregexp.h> 
+#include <qregexp.h>
 #include <qprinter.h>
-#include <qscrbar.h>
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <unistd.h>
+#include <kapp.h>
+#include <kconfig.h>
+#include <ktoolbar.h>
 
+#include <kstatusbar.h>
+#include <ktmainwindow.h>
 
 #include <X11/X.h>
 #include <X11/Xlib.h>
@@ -64,24 +63,9 @@
 
 #include "faxexpand.h"
 
-#include <kfm.h>
-#include <kapp.h>
-#include <klocale.h>
-#include <kurl.h>
-#include <kconfig.h>
-#include <ktoolbar.h>
-
-#include <kstatusbar.h>
-#include <ktopwidget.h>
-#include <kbutton.h>
-
 #include "print.h"
 #include "options.h"
 
-#ifndef DOCS_PATH
-#define DOCS_PATH "/usr/local/kde/doc/HTML/kfax/kfax.html"
-#endif
-
 #define Pimage(p)	((XImage *)(p)->extra)
 
 // StatusBar field IDs
@@ -108,35 +92,29 @@
 typedef KToolBar::BarPosition BarPosition;
 
 class MyApp:public KApplication {
-
 public:
-
-  MyApp( int &argc, char **argv, const QString& rAppName );
    virtual bool x11EventFilter( XEvent * );
-
 };
 
-class TopLevel : public KTopLevelWidget
+class TopLevel : public KTMainWindow
 {
     Q_OBJECT
 
 
 public:
 
-    enum action { GET, PUT };
-    
     TopLevel( QWidget *parent=0, const char *name=0 );
     ~TopLevel();
 
-    void openNetFile( const char *_url);
-    void saveNetFile( const char *_url );
+    void openNetFile( const QString& _url);
+    void saveNetFile( const QString& _url );
 
     static QList<TopLevel> windowList;
     QPopupMenu *file, *view, *help,*options,*right_mouse_button, *colors;
-    
+
     void closeEvent( QCloseEvent *e );
 
-    void setFaxTitle(char* name);
+    void setFaxTitle(const QString& name);
     void setStatusBarMemField(int mem);
     void handle_X_event(XEvent Event);
     void putImage();
@@ -145,6 +123,7 @@ public:
 protected:
 
     void resizeEvent(QResizeEvent *);
+    void dropEvent( QDropEvent * event );
 
     void setSensitivity();
 
@@ -153,9 +132,9 @@ protected:
     void setupMenuBar();
     void setupToolBar();
     void setupEditWidget();
-    void setupStatusBar();        
+    void setupStatusBar();
 
-private:    
+private:
 
 
     int statusID, toolID, indentID;
@@ -181,18 +160,16 @@ private:
     QScrollBar *	hsb;
     QScrollBar *	vsb;
     QFrame* 	mainpane;
-    KFM * kfm;
     QString tmpFile;
     QString netFile;
-    action kfmAction;
-    
+
     PrintDialog * printdialog;
     struct printinfo pi;
 
 public slots:
 
     void set_colors();
-    void pageActivated(const char*);
+    void pageActivated(const QString&);
     void saving_slot();
     void loading_slot();
     void setGeneralStatusField(QString string);
@@ -202,7 +179,6 @@ public slots:
     void file_save_url();
     void quiteditor();
     void file_open();
-//    QFileDialog* getFileDialog(const char* captiontext);
     void toolbarClicked( int );
     void zoomin();
     void zoomout();
@@ -210,7 +186,6 @@ public slots:
     void file_close();
     void file_save();
     void file_save_as();
-//    void about();
     void helpselected();
     void helpshort();
     void toggleStatusBar();
@@ -238,11 +213,8 @@ public slots:
     void scrollHorz(int);
     void scrollVert(int);
     void toolbarMoved(BarPosition);
-
-    void slotKFMFinished();
-    void slotDropEvent( KDNDDropZone * _dropZone );
 };
 
-void kfaxerror(char*,char*);
+void kfaxerror(const QString&, const QString&);
 
 #endif
