@@ -1,4 +1,3 @@
-
 /*
 
  KFax -- A G3/G4 Fax Viewer
@@ -37,8 +36,14 @@
 #include <sys/time.h>
 #include <unistd.h>
 
-//#include <kapp.h>
-//#include <klocale.h>
+#include <qdir.h>
+#include <qfile.h>
+#include <qevent.h>
+#include <qprinter.h>
+#include <qstring.h>
+
+#include <kcmdlineargs.h>
+#include <klocale.h>
 
 /* NewImage() needs to fiddle with the Display structure */
 #define XLIB_ILLEGAL_ACCESS
@@ -53,10 +58,6 @@
 #include "faxexpand.h"
 #include "version.h"
 
-
-
-//#define i18n klocale->translate
-
 #define VIEWFAXVERSION "2.3"
 
 
@@ -102,16 +103,16 @@ extern int qwindow_width;
 extern int qwindow_height;
 
 extern void setstatusbarmem(int);
-extern void setfaxtitle(char*);
-extern void kfaxerror(char* title,char* error);
+extern void setfaxtitle(const QString& name);
+extern void kfaxerror(const QString& title, const QString& error);
 
 struct pagenode *firstpage, *lastpage, *thispage, *helppage, *auxpage;
 struct pagenode defaultpage;
 
-static Display *Disp;
+Display *Disp;
 
-static int Default_Screen;
-char *ProgName;
+int Default_Screen;
+const char *ProgName;
 int verbose = 0;
 
 int abell = 1;			/* audio bell */
@@ -148,27 +149,30 @@ static char Banner[] =
 "KFax comes with ABSOLUTELY NO WARRANTY; for details see the\n"
 "file \"COPYING\" in the distribution directory.\n";*/
 
-static char Usage[] = "usage: %s <flags> file ...\n"\
-"\t-f\tfine resolution\n"\
-"\t-n\tnormal resolution\n"\
-"\t-h\theight (number of fax lines)\n"\
-"\t-w\twidth (dots per fax line)\n"\
-"\t-l\tturn image 90 degrees (landscape mode)\n"\
-"\t-u\tturn image upside down\n"\
-"\t-i\tinvert (black/white)\n"\
-"\t-m\tmemory usage limit in bytes (M m mega, K k kilo) default:8 megs\n"\
-"\t-r\tfax data is packed ls-bit first in input bytes\n"\
-"\t-v\tversion information\n"\
-"\t-2\traw files are g3-2d\n"\
-"\t-4\traw files are g4\n";
-
-
-
-extern "C"{
-extern int  getopt(int argc, char * const argv[],const char *optstring);
-extern char *optarg;
-extern int optind,opterr,optopt;
-}
+static KCmdLineOptions options[] =
+{
+   {"f", 0, 0 },
+   {"fine", 		I18N_NOOP("Fine resolution"), 0 },
+   {"n", 0, 0 },
+   {"normal", 		I18N_NOOP("Normal resolution"), 0 },
+   {"height", 		I18N_NOOP("Height (number of fax lines)"), 0 },
+   {"w", 0, 0 },
+   {"width", 		I18N_NOOP("Width (dots per fax line)"), 0 },
+   {"l", 0, 0 },
+   {"landscape", 	I18N_NOOP("Turn image 90 degrees (landscape mode)"), 0 },
+   {"u", 0, 0 },
+   {"upsidedown", 	I18N_NOOP("Turn image upside/down"), 0 },
+   {"i", 0, 0 },
+   {"invert", 		I18N_NOOP("Invert black and white."), 0 },
+   {"m", 0, 0 },
+   {"mem <bytes>", 	I18N_NOOP("Limit memory use to 'bytes'."), "8M" },
+   {"r", 0, 0 },
+   {"reverse", 		I18N_NOOP("Fax data is packed lsb first"), 0 },
+   {"2" , 		I18N_NOOP("Raw files are g3-2d"), 0 },
+   {"4",	 	I18N_NOOP("Raw files are g4"), 0 },
+   {"+file(s)", 	I18N_NOOP("Fax file(s) to show"), 0 },
+   { 0, 0, 0 },
+};
 
 #define MAXZOOM	10
 
@@ -178,16 +182,19 @@ XSizeHints size_hints;
 
 Time Lasttime = 0; 
 
-struct pagenode *viewpage = NULL;  
+struct pagenode *viewpage = 0;  
 
-int viewfaxmain(int argc, char **argv){
+void
+viewfax_addCmdLineOptions()
+{
+  KCmdLineArgs::addCmdLineOptions( options );
+}
 
-    int c;
-    int err  =0;
+int viewfaxmain()
+{
     int banner = 0;
     int have_height = 0;
 
-
     bo.i = 1;
     defaultpage.vres = -1;
     have_no_fax = TRUE;
@@ -195,123 +202,93 @@ int viewfaxmain(int argc, char **argv){
     /* TODO Do I need to know this: */
     defaultpage.expander = g31expand;
 
-    opterr = 0;			/* suppress getopt error message */
-
     ProgName = "KFax";
 
-    while ((c = getopt(argc, argv, "b:d:fg:h:ilm:nruvw:z:24")) != -1)
-	switch(c) {
-	
-	case '2':
-	    defaultpage.expander = g32expand;
-	    if(!have_height)
-	      defaultpage.height = 2339;
-	    have_cmd_opt = TRUE;
-	    break;
-	case 'h':               /* user thinks this is the height */
-	  have_height = 1;
-	  defaultpage.height = atoi(optarg);
-	    have_cmd_opt = TRUE;
-	  break;
-	case 'i':		/* invert black/white */
-	    defaultpage.inverse = 1;
-	    have_cmd_opt = TRUE;
-	    break;
-	case 'l':		/* landscape */
-	    defaultpage.orient |= TURN_L;
-	    have_cmd_opt = TRUE;
-	    break;
-	case 'f':		/* fine resolution */
-	    defaultpage.vres = 1;
-	    have_cmd_opt = TRUE;
-	    break;
-	case 'n':		/* normal resolution */
-	    defaultpage.vres = 0;
-	    have_cmd_opt = TRUE;
-	    break;
-	case 'r':		/* reverse input bits */
-	    defaultpage.lsbfirst = 1;
-	    have_cmd_opt = TRUE;
-	    break;
-	case 'u':		/* upside down */
-	    defaultpage.orient |= TURN_U;
-	    have_cmd_opt = TRUE;
-	    break;
-	case 'v':		/*version*/
-	    banner = 1;
-	    break;
-	case 'w':		/* user thinks this is the width */
-	    defaultpage.width = atoi(optarg);
-	    have_cmd_opt = TRUE;
-	    break;
-	case '4':
-	    defaultpage.expander = g4expand;
-	    if(!have_height)
-	      defaultpage.height = 2155;
-	    have_cmd_opt = TRUE;
-	    break;
-	    /*	case 'z':	
-	    c = atoi(optarg);
-	    if (c <= 0)
-		c = 1;
-	    for (zfactor = 1; c > 1; c >>= 1)
-		zfactor <<= 1;
-	    break;*/
-	case 'm':		/* memory usage limit */
-	    Memlimit = atoi(optarg);
-	    switch(optarg[strlen(optarg)-1]) {
+    KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+
+    if (args->isSet("height"))
+    {
+       have_height = 1;
+       defaultpage.height = args->getOption("height").toInt();
+    }
+
+    if (args->isSet("2"))
+    {
+       defaultpage.expander = g32expand;
+       if(!have_height)
+          defaultpage.height = 2339;
+    }
+
+    if (args->isSet("4"))
+    {
+       defaultpage.expander = g4expand;
+       if(!have_height)
+          defaultpage.height = 2155;
+    }
+
+    if (args->isSet("invert"))
+    {
+       defaultpage.inverse = 1;
+    }
+
+    if (args->isSet("landscape"))
+    {
+       defaultpage.orient |= TURN_L;
+    }
+
+    if (args->isSet("fine"))
+    {
+       defaultpage.vres = 1;
+    }
+
+    if (!args->isSet("rmal")) // "normal" is interpreted as "no"+"rmal" :-)
+    {
+       defaultpage.vres = 0;
+    }
+ 
+    if (args->isSet("reverse"))
+    {
+       defaultpage.lsbfirst = 1;
+    }
+
+    if (args->isSet("upsidedown"))
+    {
+       defaultpage.orient |= TURN_U;
+    }
+
+    if (args->isSet("width"))
+    {
+       defaultpage.width = args->getOption("width").toInt();
+    }
+
+    QCString mem = args->getOption("mem");
+    Memlimit = atoi(mem.data());
+    switch(mem[mem.length()-1]) {
 	    case 'M':
 	    case 'm':
 		Memlimit *= 1024;
 	    case 'K':
 	    case 'k':
 		Memlimit *= 1024;
-	    }
-	    break;
-	default:
-	    err++;
-	    break;
-
-	    /*
-	    defaultpage.vres = 1;
-	    defaultpage.height = atoi(optarg);
-	    defaultpage.inverse = 1;
-	    defaultpage.orient |= TURN_L;
-	    Memlimit = 
-	    defaultpage.vres = 0;
-	    defaultpage.lsbfirst = 1;
-	    defaultpage.orient |= TURN_U;
-	    verbose = 1;
-	    defaultpage.width = atoi(optarg);
-	    defaultpage.height = atoi(optarg);
-	    c = atoi(optarg);
-	    defaultpage.expander = g32expand;
-	    defaultpage.expander = g4expand;
-	    */
-
-	}
+    }
 
     if (defaultpage.expander == g4expand && defaultpage.height == 0) {
-	fputs("-h value is required to interpret raw g4 faxes\n", stderr);
-	err++;
+	KCmdLineArgs::usage("--height value is required to interpret raw g4 faxes\n");
     }
 
-    firstpage = lastpage = thispage = helppage = auxpage =  NULL;
+    firstpage = lastpage = thispage = helppage = auxpage =  0;
 
-    for (; optind < argc; optind++){
-	(void) notetiff(argv[optind]);
+    for (int i = 0; i < args->count(); i++){
+	(void) notetiff(QFile::decodeName(args->arg(i)));
     }
+    args->clear();
 
-    if (err ) {
-      fprintf(stderr, Usage,ProgName);
-      exit(1);
-    }
     if (banner ) {
       fprintf(stderr, Banner);
       exit(1);
     }
 
-    if ( firstpage == NULL) {
+    if ( firstpage == 0) {
       have_no_fax = TRUE;
     }
     else{
@@ -342,7 +319,7 @@ void TurnFollowing(int How, struct pagenode *pn)
     while (pn) {
 	if (Pimage(pn)) {
 	    FreeImage(Pimage(pn));
-	    pn->extra = NULL;
+	    pn->extra = 0;
 	}
 	pn->orient ^= How;
 	pn = pn->next;
@@ -362,7 +339,7 @@ drawline(pixnum *run, int LineNum, struct pagenode *pn)
 
     LineNum += pn->stripnum * pn->rowsperstrip;
     p = (t32bits *) (Pimage(pn)->data + LineNum*(2-pn->vres)*Pimage(pn)->bytes_per_line);
-    p1 =(t32bits *)( pn->vres ? NULL : p + Pimage(pn)->bytes_per_line/sizeof(*p));
+    p1 =(t32bits *)( pn->vres ? 0 : p + Pimage(pn)->bytes_per_line/sizeof(*p));
     r = run;
     acc = 0;
     nacc = 0;
@@ -408,7 +385,7 @@ GetPartImage(struct pagenode *pn, int n)
 {
     unsigned char *Data = getstrip(pn, n);
 
-    if (Data == NULL)
+    if (Data == 0)
 	return 3;
     pn->stripnum = n;
     (*pn->expander)(pn, drawline);
@@ -419,23 +396,23 @@ GetPartImage(struct pagenode *pn, int n)
 int GetImage(struct pagenode *pn){
     int i;
 
-    if (pn->strips == NULL) {
+    if (pn->strips == 0) {
 
       /*printf("RAW fax file\n");*/
 
 	/* raw file; maybe we don't have the height yet */
 	unsigned char *Data = getstrip(pn, 0);
-	if (Data == NULL){
+	if (Data == 0){
 
 	  return 0;
 	}
 	pn->extra = NewImage(pn->width, pn->vres ?
-			     pn->height : 2*pn->height, NULL, 1);
+			     pn->height : 2*pn->height, 0, 1);
 
 //printf("height = %d\n",pn->height);
 //printf("setting height to %d\n", pn->vres ? pn->height : 2*pn->height);
 
-	if(pn->extra == NULL)
+	if(pn->extra == 0)
 	  return 0;
 
 	(*pn->expander)(pn, drawline);
@@ -445,9 +422,9 @@ int GetImage(struct pagenode *pn){
       /*printf("MULTI STRIP TIFF fax file\n");*/
 
 	pn->extra = NewImage(pn->width, pn->vres ?
-			     pn->height : 2*pn->height, NULL, 1);
+			     pn->height : 2*pn->height, 0, 1);
 
-	if(pn->extra == NULL)
+	if(pn->extra == 0)
 	  return 0;
 	pn->stripnum = 0;
 	for (i = 0; i < pn->nstrips; i++){
@@ -533,9 +510,9 @@ XImage *ZoomImage(XImage *Big){
     XFlush(Disp);
     w = (Big->width+1) / 2;
     h = (Big->height+1) / 2;
-    Small = NewImage(w, h, NULL, Big->bitmap_bit_order);
-    if(Small == NULL)
-      return NULL;
+    Small = NewImage(w, h, 0, Big->bitmap_bit_order);
+    if(Small == 0)
+      return 0;
 
     Small->xoffset = (Big->xoffset+1)/2;
     for (i = 0; i < Big->height; i += 2) {
@@ -591,8 +568,8 @@ XImage *FlipImage(XImage *Image){
 
     XImage *New = NewImage(Image->width, Image->height,
 			   Image->data, !Image->bitmap_bit_order);
-    if(New == NULL)
-      return NULL;
+    if(New == 0)
+      return 0;
 
     t32bits *p1 = (t32bits *) Image->data;
     t32bits *p2 = (t32bits *) (Image->data + Image->height *
@@ -609,7 +586,7 @@ XImage *FlipImage(XImage *Image){
     New->xoffset = 32 - (Image->width & 31) - Image->xoffset;
     New->xoffset &= 31;
 
-    Image->data = NULL;
+    Image->data = 0;
     FreeImage(Image);
     return New;
 }
@@ -619,8 +596,8 @@ XImage *MirrorImage(XImage *Image){
     int i;
     XImage *New = NewImage(Image->width, Image->height,
 			   Image->data, !Image->bitmap_bit_order);
-    if(New == NULL)
-      return NULL;
+    if(New == 0)
+      return 0;
 
     /* reverse order of 32-bit words in each line */
     for (i = 0; i < Image->height; i++) {
@@ -637,7 +614,7 @@ XImage *MirrorImage(XImage *Image){
     New->xoffset = 32 - (Image->width & 31) - Image->xoffset;
     New->xoffset &= 31;
 
-    Image->data = NULL;
+    Image->data = 0;
     FreeImage(Image);
     return New;
 }
@@ -651,9 +628,9 @@ XImage *RotImage(XImage *Image){
     int order = Image->bitmap_bit_order;
     int offs = h+Image->xoffset-1;
 
-    New = NewImage(w, h, NULL, 1);
-    if (New == NULL)
-      return NULL;
+    New = NewImage(w, h, 0, 1);
+    if (New == 0)
+      return 0;
 
     k = (32 - Image->xoffset) & 3;
     for (i = h - 1; i && k; i--, k--) {
@@ -745,7 +722,7 @@ XImage *RotImage(XImage *Image){
 #define Try(n)								\
     if (n && n != thispage && n->extra) {				\
 	FreeImage((XImage*)n->extra);	\
-	n->extra = NULL;						\
+	n->extra = 0;						\
 	return 1;							\
     }
 
@@ -762,7 +739,7 @@ release(int quit)
 	    if (pn->extra && pn != thispage && pn != thispage->prev &&
 		pn != thispage->next && pn != lastpage) {
 		FreeImage(Pimage(pn));
-		pn->extra = NULL;
+		pn->extra = 0;
 		return 1;
 	    }
 	Try(lastpage);
@@ -784,14 +761,14 @@ XImage *NewImage(int w, int h, char *data, int bit_order){
     Display fake;
 
     fake = *Disp;
-    if (data == NULL)
+    if (data == 0)
 	data = xmalloc(((w + 31) & ~31) * h / 8);
     fake.byte_order = ByteOrder;
     fake.bitmap_bit_order = bit_order;
 
     int returncode = -1;
     while ((newimage = XCreateImage(&fake, DefaultVisual(Disp, Default_Screen),
-				    1, XYBitmap, 0, data, w, h, 32, 0)) == NULL ){
+				    1, XYBitmap, 0, data, w, h, 32, 0)) == 0 ){
       
       returncode = release(1);
       if (returncode == 0)
@@ -800,7 +777,7 @@ XImage *NewImage(int w, int h, char *data, int bit_order){
 
     if (returncode == 0){
       kfaxerror("Sorry","Can not allocate Memory for a new Fax Image\n");
-      return NULL;
+      return 0;
     }
 
     Memused += newimage->bytes_per_line * newimage->height;
@@ -833,7 +810,7 @@ xmalloc(unsigned int size)
 
     while (Memused + size > Memlimit && release(0))
 	;
-    while ((p = (char*) malloc(size)) == NULL)
+    while ((p = (char*) malloc(size)) == 0)
 	(void) release(1);
     return p;
 }
