@@ -17,15 +17,15 @@
 
 #include <qaccel.h>
 #include <qlayout.h>
-#include <qradiobt.h>
-#include <qgrpbox.h>
+#include <qradiobutton.h>
+#include <qgroupbox.h>
 #include <qvalidator.h>
 
-
 #include <klocale.h>
 #include <kapp.h>
 #include <kbuttonbox.h>
-#include <qmsgbox.h>
+#include <kconfig.h>
+#include <kmessagebox.h>
 
 PrintSetup::PrintSetup( QWidget *parent, const char *name, QString pname,
 				QString spooler, QString variable )
@@ -110,24 +110,22 @@ PrintSetup::PrintSetup( QWidget *parent, const char *name, QString pname,
 	topLayout->addWidget( bbox );
 
 	topLayout->activate();
-	
-	resize( 300,0 );
 }
 
 PrintDialog::PrintDialog( QWidget *parent, const char *name, int maxPages,
-							bool marked )		
+							bool marked )
 	: QDialog( parent, name, TRUE )
 {
 	setFocusPolicy(QWidget::StrongFocus);
 	
 	pgMode = All;
 	/*
-	printerName.sprintf( "" ); // default printer will be chosen.
-	spoolerCommand.sprintf( "lpr" );
-	printerVariable.sprintf( "PRINTER" );
+	printerName = ""; // default printer will be chosen.
+	spoolerCommand = "lpr";
+	printerVariable = "PRINTER";
 	*/
 
-	KConfig *config = KApplication::getKApplication()->getConfig();
+	KConfig *config = KApplication::kApplication()->config();
 	/* Read in the default options. */
 	config->setGroup( "Print" );
 	printerName=config->readEntry ("Name","");
@@ -173,43 +171,37 @@ PrintDialog::PrintDialog( QWidget *parent, const char *name, int maxPages,
 	
 	int widest = 0;
 	
-	QRadioButton *arb = new QRadioButton( i18n("&All"), group );
-	arb->setFixedHeight( arb->sizeHint().height()+6 );
-	arb->setChecked( true );
-	pgGroup->insert( arb, All );
-	
-	grid->addWidget( arb, 1, 1 );
-	
-	if ( arb->sizeHint().width() > widest )
-	  widest = arb->sizeHint().width();
-	
-	QRadioButton *rb = new QRadioButton( i18n("&Current"), group );
+	QRadioButton *rb = new QRadioButton( i18n("&All"), group );
 	rb->setFixedHeight( rb->sizeHint().height()+6 );
-	pgGroup->insert( rb, Current );
+	rb->setChecked( true );
+	pgGroup->insert( rb, All );
 	
-	grid->addWidget( rb, 1, 2 );
+	grid->addWidget( rb, 1, 1 );
 	
 	if ( rb->sizeHint().width() > widest ) widest = rb->sizeHint().width();
 	
+	rb = new QRadioButton( i18n("&Current"), group );
+	rb->setFixedHeight( rb->sizeHint().height()+6 );
+    pgGroup->insert( rb, Current );
+	
+	grid->addWidget( rb, 1, 2 );
+
+	if ( rb->sizeHint().width() > widest ) widest = rb->sizeHint().width();
+		
 	rb = new QRadioButton( i18n("&Marked"), group );
 	rb->setFixedHeight( rb->sizeHint().height()+6 );
 	if ( !marked )
 	  rb->setEnabled( false );
-	else
-	  {
-	    arb->setChecked ( false );
-	    rb->setChecked ( true );
-	  }
 
 	pgGroup->insert( rb, Marked );
 	
 	grid->addWidget( rb, 3, 1 );
-	
+
 	if ( rb->sizeHint().width() > widest ) widest = rb->sizeHint().width();
 	
 	rb = new QRadioButton( i18n("&Range"), group );
 	rb->setFixedHeight( rb->sizeHint().height()+6 );
-	pgGroup->insert( rb, Range );
+    pgGroup->insert( rb, Range );
 	
 	grid->addWidget( rb, 3, 2 );
 	
@@ -224,7 +216,7 @@ PrintDialog::PrintDialog( QWidget *parent, const char *name, int maxPages,
 	lTo->setText( i18n("to") );
 	lTo->setAlignment( AlignCenter );
 	lTo->setMinimumSize( lTo->sizeHint() );
-	
+
 	grid->addWidget( lTo, 3, 4 );
 	
 	leEnd = new QLineEdit( group );
@@ -267,57 +259,55 @@ PrintDialog::PrintDialog( QWidget *parent, const char *name, int maxPages,
 	topLayout->addWidget( bbox );
 	
 	topLayout->activate();
-	
-	if ( marked )
-	  slotPageMode( Marked );
+
+	if (marked)
+	  slotPageMode (Marked);
 	else
 	  slotPageMode( All );
-
-	resize( 250, 0 );
-	
 }
 
 void PrintDialog::setup()
 {
-	PrintSetup *ps = new PrintSetup( this, "print setup", printerName,
-		 spoolerCommand, printerVariable );
-		
-		
-
-	if( ps->exec() ) {
-
-	printerName.sprintf( ps->leName->text() );
-	spoolerCommand.sprintf( ps->leSpool->text() );
-	printerVariable.sprintf( ps->leVar->text() );
-
-	/* Set the default options. */
-	KConfig *config = KApplication::getKApplication()->getConfig();
-
-	config->setGroup( "Print" );
-	config->writeEntry ("Name", (const char *)printerName);
-	config->writeEntry ("Spool", (const char *)spoolerCommand);
-	config->writeEntry ("Variable", (const char*)printerVariable);
-	config->sync();
-
-        delete ps;
-	}
+  PrintSetup *ps = new PrintSetup( this, "print setup", printerName,
+				   spoolerCommand, printerVariable );
+  
+  
+  
+  if( ps->exec() ) {
+    
+    printerName = ps->leName->text();
+    spoolerCommand = ps->leSpool->text();
+    printerVariable = ps->leVar->text();
+    
+    /* Set the default options. */
+    KConfig *config = KApplication::kApplication()->config();
+    
+    config->setGroup( "Print" );
+    config->writeEntry ("Name", (const char *)printerName);
+    config->writeEntry ("Spool", (const char *)spoolerCommand);
+    config->writeEntry ("Variable", (const char*)printerVariable);
+    config->sync();
+    
+    delete ps;
+  }
 }
 
 void PrintDialog::checkRange()
 {
   if ( pgMode == Range ) {
-	
+    
     if ( QString( leStart->text() ).toInt() < 1 
 	 || QString( leStart->text() ).toInt() > pgMax
 	 || QString( leEnd->text() ).toInt() < 1 
 	 || QString( leEnd->text() ).toInt() > pgMax ) {
       
-      QMessageBox::critical( 0, i18n( "Range error" ),
-			     i18n(	"The range of pages entered for printing\n"\
-					"can't be understood.\n\n"\
-					"The range specified must lie within the page\n"\
-					"range for this part of the document.\n"\
-					"Check the status bar for this information.\n" ) );
+      KMessageBox::error( 0,
+			  i18n(	"The range of pages entered for printing\n"\
+				"can't be understood.\n\n"\
+				"The range specified must lie within the page\n"\
+				"range for this part of the document.\n"\
+				"Check the status bar for this information.\n" ),
+			  i18n("Range error") );
       return;
     }
   }
@@ -329,22 +319,20 @@ void PrintDialog::slotPageMode( int m )
 {
   pgMode = m;
   
-  switch ( pgMode ) {
-    
-  case Range:
-    
-    leStart->setEnabled( true );
-    leEnd->setEnabled( true );
-    lTo->setEnabled( true );
-    break;
-    
-  default:
-    
-    leStart->setEnabled( false );
-    leEnd->setEnabled( false );
-    lTo->setEnabled( false );
-    break;
-  }
+  switch ( pgMode )
+    {
+    case Range:
+      leStart->setEnabled( true );
+      leEnd->setEnabled( true );
+      lTo->setEnabled( true );
+      break;
+      
+    default:
+      leStart->setEnabled( false );
+      leEnd->setEnabled( false );
+      lTo->setEnabled( false );
+      break;
+    }
 }
 
 
