@@ -342,7 +342,7 @@ file = *fileP;
 	char s[512];
 	filename_dsc=file_getTmpFilename(tmpprefix);
 	sprintf(cmd,cmd_scan_pdf,filename,filename_dsc);
-	fprintf(stderr, "PDF scan command:%s\n",cmd);
+	/* fprintf(stderr, "PDF scan command:%s\n",cmd); */
 	if (system(cmd) || file_fileIsNotUseful(filename_dsc)) {
 		scan_exec_failed:
 		sprintf(s,"Execution of\n%s\nfailed.",cmd);
@@ -975,36 +975,37 @@ continuepage:
 		if (strcmp(text, "(atend)") == 0) {
 		    page_bb_set = ATEND;
 		} else {
-		    if (sscanf(line+length("%%PageBoundingBox:"), "%d %d %d %d",
-			    &(doc->pages[doc->numpages].boundingbox[LLX]),
-			    &(doc->pages[doc->numpages].boundingbox[LLY]),
-			    &(doc->pages[doc->numpages].boundingbox[URX]),
-			    &(doc->pages[doc->numpages].boundingbox[URY])) == 4)
-			if (page_bb_set == NONE) page_bb_set = 1;
-		    else {
-			float fllx, flly, furx, fury;
-			if (sscanf(line+length("%%PageBoundingBox:"),
-				   "%f %f %f %f",
-				   &fllx, &flly, &furx, &fury) == 4) {
-			    if (page_bb_set == NONE) page_bb_set = 1;
-			    doc->pages[doc->numpages].boundingbox[LLX] = fllx;
-			    doc->pages[doc->numpages].boundingbox[LLY] = flly;
-			    doc->pages[doc->numpages].boundingbox[URX] = furx;
-			    doc->pages[doc->numpages].boundingbox[URY] = fury;
-			    if (fllx <
-				    doc->pages[doc->numpages].boundingbox[LLX])
-				doc->pages[doc->numpages].boundingbox[LLX]--;
-			    if (flly <
-				    doc->pages[doc->numpages].boundingbox[LLY])
-				doc->pages[doc->numpages].boundingbox[LLY]--;
-			    if (furx >
-				    doc->pages[doc->numpages].boundingbox[URX])
-				doc->pages[doc->numpages].boundingbox[URX]++;
-			    if (fury >
-				    doc->pages[doc->numpages].boundingbox[URY])
-				doc->pages[doc->numpages].boundingbox[URY]++;
-			}
+		  if (sscanf(line+length("%%PageBoundingBox:"), "%d %d %d %d",
+			     &(doc->pages[doc->numpages].boundingbox[LLX]),
+			     &(doc->pages[doc->numpages].boundingbox[LLY]),
+			     &(doc->pages[doc->numpages].boundingbox[URX]),
+			     &(doc->pages[doc->numpages].boundingbox[URY])) == 4) {
+		    if (page_bb_set == NONE) page_bb_set = 1;
+		  }
+		  else {
+		    float fllx, flly, furx, fury;
+		    if (sscanf(line+length("%%PageBoundingBox:"),
+			       "%f %f %f %f",
+			       &fllx, &flly, &furx, &fury) == 4) {
+		      if (page_bb_set == NONE) page_bb_set = 1;
+		      doc->pages[doc->numpages].boundingbox[LLX] = fllx;
+		      doc->pages[doc->numpages].boundingbox[LLY] = flly;
+		      doc->pages[doc->numpages].boundingbox[URX] = furx;
+		      doc->pages[doc->numpages].boundingbox[URY] = fury;
+		      if (fllx <
+			  doc->pages[doc->numpages].boundingbox[LLX])
+			doc->pages[doc->numpages].boundingbox[LLX]--;
+		      if (flly <
+			  doc->pages[doc->numpages].boundingbox[LLY])
+			doc->pages[doc->numpages].boundingbox[LLY]--;
+		      if (furx >
+			  doc->pages[doc->numpages].boundingbox[URX])
+			doc->pages[doc->numpages].boundingbox[URX]++;
+		      if (fury >
+			  doc->pages[doc->numpages].boundingbox[URY])
+			doc->pages[doc->numpages].boundingbox[URY]++;
 		    }
+		  }
 		}
 	    }
 	}
