@@ -9,10 +9,11 @@
 **
 *****************************************************************************/
 
-#include <qcombo.h>
+#include <qcombobox.h>
 #include <qframe.h>
-#include <qgrpbox.h>
+#include <qgroupbox.h>
 #include <qlabel.h>
+#include <qpushbutton.h>
 #include <qlayout.h>
 
 #include "viewcontrol.h"
@@ -37,7 +38,7 @@ ViewControl::ViewControl( QWidget *parent, const char *name )
 	
 	topLayout->addWidget( vcGroupBox, 10 );
 	
-	QGridLayout *grid = new QGridLayout( vcGroupBox, 2, 2, 10 );
+	QGridLayout *grid = new QGridLayout( vcGroupBox, 3, 2, 10 );
 	
 	grid->setRowStretch(0,0);
 	grid->setRowStretch(1,10);
@@ -49,34 +50,39 @@ ViewControl::ViewControl( QWidget *parent, const char *name )
 
 	magComboBox = new QComboBox( FALSE, vcGroupBox );
 	magComboBox->setFixedHeight( magComboBox->sizeHint().height() );
-	connect ( magComboBox, SIGNAL (activated (int)),
-		  SLOT (disableApply (int)) );
-	magComboBox->hide();
 
-	//grid->addWidget( magComboBox, 0, 1 );
+     
+	//magComboBox->hide();
+
+	connect ( magComboBox, SIGNAL (activated (int)),
+		  this, SLOT (slotMagSelection (int)) );
+	grid->addWidget( magComboBox, 0, 1 );
+
+
 	
 	mediaComboBox = new QComboBox( FALSE, vcGroupBox );
 	mediaComboBox->setFixedHeight( magComboBox->sizeHint().height() );
-	connect ( mediaComboBox, SIGNAL (activated (int)),
-		  SLOT (disableApply (int)) );
 	
-	grid->addWidget( mediaComboBox, 0, 1 );
+	connect ( mediaComboBox, SIGNAL (activated (int)),
+		  this, SLOT (slotMediaSelection (int)) );
+
+	grid->addWidget( mediaComboBox, 1, 1 );
 	
 	orientComboBox = new QComboBox( FALSE, vcGroupBox );
 	orientComboBox->insertItem(i18n("Portrait"));
 	orientComboBox->insertItem(i18n("Landscape"));
-	orientComboBox->insertItem(i18n("Upside down"));
 	orientComboBox->insertItem(i18n("Seascape"));
+	orientComboBox->insertItem(i18n("Upside down"));
 	orientComboBox->setFixedHeight( magComboBox->sizeHint().height() );
+			
 	connect ( orientComboBox, SIGNAL (activated (int)),
-		  SLOT (disableApply (int)) );
-					
-	grid->addWidget( orientComboBox, 1, 1 );
+		  this, SLOT (slotOrientSelection (int)) );
+	grid->addWidget( orientComboBox, 2, 1 );
 		
 	int labelWidth = 0;
 
 	QLabel* vcLabel;
-	vcLabel = new QLabel( magComboBox, i18n("magnification"), vcGroupBox );
+	vcLabel = new QLabel( magComboBox, i18n("&Magnification"), vcGroupBox );
 	vcLabel->setAlignment( AlignRight | AlignVCenter | ShowPrefix );
 	if ( vcLabel->sizeHint().width() > labelWidth )
 		labelWidth = vcLabel->sizeHint().width();
@@ -84,15 +90,16 @@ ViewControl::ViewControl( QWidget *parent, const char *name )
 
 	vcLabel->hide();
 
-	//grid->addWidget( vcLabel, 0, 0 );
+	grid->addWidget( vcLabel, 0, 0 );
 
-	vcLabel = new QLabel( mediaComboBox, i18n("&Media"), vcGroupBox );
+
+	vcLabel = new QLabel( mediaComboBox, i18n("M&edia"), vcGroupBox );
 	vcLabel->setAlignment( AlignRight | AlignVCenter | ShowPrefix );
 	if ( vcLabel->sizeHint().width() > labelWidth )
 		labelWidth = vcLabel->sizeHint().width();
 	vcLabel->setMinimumWidth( labelWidth );
 	
-	grid->addWidget( vcLabel, 0, 0 );
+	grid->addWidget( vcLabel, 1, 0 );
 	
 	vcLabel = new QLabel( orientComboBox, i18n("&Orientation"), vcGroupBox );
 	vcLabel->setAlignment( AlignRight | AlignVCenter | ShowPrefix );
@@ -100,7 +107,7 @@ ViewControl::ViewControl( QWidget *parent, const char *name )
 		labelWidth = vcLabel->sizeHint().width();
 	vcLabel->setMinimumWidth( labelWidth );
 	
-	grid->addWidget( vcLabel, 1, 0 );
+	grid->addWidget( vcLabel, 2, 0 );
 	
 	vcGroupBox->setMinimumHeight( 2*orientComboBox->sizeHint().height()+20 );
 	vcGroupBox->setMinimumWidth(
@@ -118,14 +125,11 @@ ViewControl::ViewControl( QWidget *parent, const char *name )
 	KButtonBox *bbox = new KButtonBox( this );
 	bbox->addStretch( 10 );
 
-	okButton = bbox->addButton( i18n("&OK") );
-	connect( okButton, SIGNAL(clicked()), SLOT(slotOKClicked()) );
+	apply = bbox->addButton( i18n("&Apply") );
+	connect( apply, SIGNAL(clicked()), SLOT(slotApplyClicked()) );
 
-	applyButton = bbox->addButton( i18n("&Apply") );
-	connect( applyButton, SIGNAL(clicked()), SLOT(slotApplyClicked()) );
-
-	QPushButton *close = bbox->addButton( i18n("&Close") );
-	connect( close, SIGNAL(clicked()), SLOT(reject()) );
+	QPushButton *closebtn = bbox->addButton( i18n("&Close") );
+	connect( closebtn, SIGNAL(clicked()), SLOT(reject()) );
 
 
 	bbox->layout();
@@ -133,37 +137,58 @@ ViewControl::ViewControl( QWidget *parent, const char *name )
 
 	topLayout->activate();
 
-	applyButton->setEnabled (false);
-	okButton->setEnabled (false);
-	
-	resize( 250 ,0);
+	prevmag = prevmedia = prevorient = 0;
+	applyEnable (false);
+}
+
+void
+ViewControl::updateMag (int mag)
+{
+  magComboBox->setCurrentItem (mag);
+  prevmag = mag;
+}
+
+
+void
+ViewControl::applyEnable (bool enable)
+{
+  apply->setEnabled (enable);
 }
 
 void
 ViewControl::slotApplyClicked()
 {
   emit applyChanges();
-  applyButton->setEnabled (false);
-  okButton->setEnabled (false);
-}
-
-
-void
-ViewControl::slotOKClicked()
-{
-  emit applyChanges();
-  hide();
+  applyEnable (false);
 }
 
 void
-ViewControl::updateOrientation(int orientation)
+ViewControl::slotMagSelection (int i)
 {
-  orientComboBox->setCurrentItem (orientation);
+  if (i != prevmag)
+    {
+      applyEnable (true);
+      prevmag = i;
+    }
 }
 
 void
-ViewControl::disableApply (int)
+ViewControl::slotMediaSelection (int i)
 {
-  applyButton->setEnabled (true);
-  okButton->setEnabled (true);
+  if (i != prevmedia)
+    {
+      applyEnable (true);
+      prevmedia = i;
+    }
 }
+
+void
+ViewControl::slotOrientSelection (int i)
+{
+  if (i != prevorient)
+    {
+      applyEnable (true);
+      prevorient = i;
+    }
+}
+
