@@ -1,7 +1,8 @@
 
 #include "debug.h"
-#include <kmsgbox.h>
+#include <kmessagebox.h>
 #include <kapp.h>
+#include <klocale.h>
 
 void myMessageOutput( QtMsgType type, const char *msg )    
 {
@@ -13,15 +14,13 @@ void myMessageOutput( QtMsgType type, const char *msg )
 #endif
        break;
      case QtWarningMsg:
-       KMsgBox::message(0, i18n("Warning"), msg );
+       KMessageBox::sorry(0, msg);
        fprintf( stderr, "Warning: %s\n", msg );
        break;
      case QtFatalMsg:
-       KMsgBox::message(0, i18n("Fatal!"), msg );
+       KMessageBox::error(0, msg);
        fprintf( stderr, "Fatal: %s\n", msg );
        abort();
        // dump core on purpose
   }
 }
-
-
