@@ -1,14 +1,14 @@
 
 #ifndef __DEBUG_H__
 #define __DEBUG_H__
-
+/*
 #ifdef DEBUG
 #undef DEBUG
 #endif
 #define NO_DEBUG 1
+*/
 
-
-#include <qapp.h>    
+#include <qapplication.h>    
 #include <stdio.h>    
 #include <stdlib.h>
 
