@@ -5,6 +5,7 @@
 #include <kiconloader.h>
 #include <kapp.h>
 #include "kdragsource.h"
+#include <kglobal.h>
 
 KDragSource::KDragSource( const char *dragtype, QObject *dataprovider, const char *method, 
                                                QWidget *parent, const char * name )
@@ -40,11 +41,9 @@ void KDragSource::mousePressEvent( QMouseEvent * /*e*/ )
     {
       QImageDrag *di = new QImageDrag( img, this );
       debug("KDragSource::mousePressEvent - before dragCopy");
-#if QT_VERSION > 140
-      QPixmap pm(Icon("image.xpm"));
+      QPixmap pm(BarIcon("image") );
       QPoint pp(pm.width()/2, pm.height()/2);
       di->setPixmap(pm, pp);
-#endif
       di->dragCopy();
     }
   }
