@@ -16,34 +16,43 @@
     along with this library; see the file COPYING.LIB.  If not, write to
     the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
     Boston, MA 02111-1307, USA.
-*/  
+*/
 
+#include <stdlib.h>
+
+#include <qlayout.h>
+
+#include <klocale.h>
 #include <kcolordlg.h>
-#include "debug.h"
+#include <kfiledialog.h>
+#include <kmessagebox.h>
+
 #include "kiconconfig.h"
-#include "kiconfiledlg.h"
+
+#ifndef PICS_INCLUDED
+#define PICS_INCLUDED
 #include "pics/logo.xpm"
+#endif
 
 KTemplateEditDlg::KTemplateEditDlg(QWidget *parent) : QDialog(parent, 0, true)
 {
   ok = cancel = browse = 0L;
-  QGroupBox *grp = new QGroupBox(i18n("Template"), this);
-  lb_name = new QLabel(i18n("Description:"), this);
-  lb_name->setFixedHeight(lb_name->sizeHint().height());
-  lb_path = new QLabel(i18n("Path:"), this);
-  lb_path->setFixedHeight(lb_path->sizeHint().height());
 
-  ln_name = new QLineEdit(this);
-  ln_name->setFixedHeight(20);
-  connect( ln_name, SIGNAL(textChanged(const char *)), SLOT(slotTextChanged(const char*)) );
+  QGroupBox *grp = new QGroupBox(i18n("Template"), this);
+
+  QVBoxLayout *ml = new QVBoxLayout(this, 10);
+  QVBoxLayout *l = new QVBoxLayout(grp, 25);
+
+  ln_name = new QLineEdit( this );
+  connect( ln_name, SIGNAL( textChanged( const char* ) ), SLOT( slotTextChanged( const char* ) ) );
+
+  QLabel* lb_name = new QLabel( ln_name, i18n( "Description:" ), this );
 
   ln_path = new QLineEdit(this);
-  ln_path->setFixedHeight(20);
-  connect( ln_path, SIGNAL(textChanged(const char *)), SLOT(slotTextChanged(const char*)) );
+  connect( ln_path, SIGNAL( textChanged( const char* ) ), SLOT( slotTextChanged( const char* ) ) );
+
+  QLabel* lb_path = new QLabel( ln_path, i18n( "Path:" ), this );
 
-  QBoxLayout *ml = new QVBoxLayout(this, 10);
-  //ml->addWidget(grp, 10, AlignLeft);
-  QBoxLayout *l = new QVBoxLayout(grp, 25);
   l->addWidget(lb_name);
   l->addWidget(ln_name);
   l->addWidget(lb_path);
@@ -51,26 +60,22 @@ KTemplateEditDlg::KTemplateEditDlg(QWidget *parent) : QDialog(parent, 0, true)
 
   KButtonBox *bbox = new KButtonBox( this );
 	
-  ok = bbox->addButton( i18n("&OK") );
-  connect( ok, SIGNAL(clicked()), SLOT(accept()) );
+  ok = bbox->addButton( i18n( "&OK" ) );
+  connect( ok, SIGNAL( clicked() ), SLOT( accept() ) );
   ok->setEnabled(false);
 	
-  cancel = bbox->addButton( i18n("&Cancel") );
-  connect( cancel, SIGNAL(clicked()), SLOT(reject()) );
+  cancel = bbox->addButton( i18n( "&Cancel" ) );
+  connect( cancel, SIGNAL( clicked() ), SLOT( reject() ) );
 	
-  bbox->addStretch( 10 );
+  bbox->addStretch( 1 );
 		
-  browse = bbox->addButton( i18n("&Browse...") );
-  connect( browse, SIGNAL(clicked()), SLOT(slotBrowse()) );
+  browse = bbox->addButton( i18n( "&Browse..." ) );
+  connect( browse, SIGNAL( clicked() ), SLOT( slotBrowse() ) );
 		
   bbox->layout();
-  bbox->setMaximumHeight(bbox->sizeHint().height());
 
-  ml->addWidget(grp, 10, AlignLeft);
+  ml->addWidget( grp, 1);
   ml->addWidget( bbox );
-
-  l->activate();
-  ml->activate();
 }
 
 void KTemplateEditDlg::slotTextChanged(const char *)
@@ -108,52 +113,59 @@ const char *KTemplateEditDlg::getPath()
 
 void KTemplateEditDlg::slotBrowse()
 {
-  QString path = KIconFileDlg::getOpenFileName("/", "*.xpm");
-  if(!path.isEmpty())
-    setPath(path);
+  KURL url = KFileDialog::getOpenURL( getenv( "HOME" ), "*.xpm" );
+
+  if( url.isEmpty() )
+    return;
+
+  if( !url.isLocalFile() )
+  {
+    KMessageBox::sorry( 0L, i18n( "Only local files are supported yet." ) );
+    return;
+  }
+
+  setPath( url.path() );
 }
 
 KTemplateConfig::KTemplateConfig(QWidget *parent) : QWidget(parent)
 {
   debug("KTemplateConfig constructor");
-  btadd = btremove = btedit = 0L;
-  grp = new QGroupBox(i18n("Templates:"), this);
-  templates = new KIconListBox(grp);
-  connect( templates, SIGNAL(highlighted(int)), SLOT(checkSelection(int)));
 
-  ml = new QVBoxLayout(this);
-  ml->addWidget(grp);
-  l = new  QVBoxLayout(grp, 15);
-  l->addWidget(templates);
+  btadd = btremove = btedit = 0L;
+
+  QGroupBox* grp = new QGroupBox( i18n( "Templates:" ), this );
+  templates = new KIconListBox( grp );
+  connect( templates, SIGNAL( highlighted( int ) ), SLOT( checkSelection( int ) ) );
+
+  QVBoxLayout* ml = new QVBoxLayout( this, 5 );
+  ml->addWidget( grp );
+
+  QVBoxLayout* l = new  QVBoxLayout( grp, 15 );
+  l->addSpacing( 10 );
+  l->addWidget( templates );
 
   tlist = KIconTemplateContainer::getTemplates();
 
-  for(int i = 0; i < (int)tlist->count(); i++)
-    templates->insertItem(new KIconListBoxItem(tlist->at(i)));
+  for( int i = 0; i < (int) tlist->count(); i++ )
+    templates->insertItem( new KIconListBoxItem( tlist->at( i ) ) );
 
   KButtonBox *bbox = new KButtonBox( grp );
 	
-  btadd = bbox->addButton( i18n("&Add") );
-  connect( btadd, SIGNAL(clicked()), SLOT(add()) );
+  btadd = bbox->addButton( i18n( "&Add" ) );
+  connect( btadd, SIGNAL( clicked() ), SLOT( add() ) );
 	
-  btedit = bbox->addButton( i18n("&Edit") );
-  connect( btedit, SIGNAL(clicked()), SLOT(edit()) );
-  btedit->setEnabled(false);
+  btedit = bbox->addButton( i18n( "&Edit" ) );
+  connect( btedit, SIGNAL( clicked() ), SLOT( edit() ) );
+  btedit->setEnabled( false );
 	
-  btremove = bbox->addButton( i18n("&Remove") );
-  connect( btremove, SIGNAL(clicked()), SLOT(remove()) );
-  btremove->setEnabled(false);
+  btremove = bbox->addButton( i18n( "&Remove" ) );
+  connect( btremove, SIGNAL( clicked() ), SLOT( remove() ) );
+  btremove->setEnabled( false );
 		
-  bbox->addStretch( 10 );
+  bbox->addStretch( 1 );
 		
   bbox->layout();
-  bbox->setMaximumHeight(bbox->sizeHint().height());
   l->addWidget( bbox );
-
-  l->activate();
-  ml->activate();
-
-  debug("KTemplateConfig constructor - done");
 }
 
 void KTemplateConfig::saveSettings()
@@ -166,11 +178,9 @@ void KTemplateConfig::saveSettings()
     {
       KIconTemplate *it = new KIconTemplate;
       it->path = templates->path(i);
-      //it->path.detach();
       it->title = templates->text(i);
-      //it->title.detach();
       tlist->append(it);
-      debug("Name: %s\nPath: %s", templates->text(i), templates->path(i).data());
+      debug("Name: %s\nPath: %s", templates->text(i).data(), templates->path(i).data());
       debug("Name: %s\nPath: %s", it->path.data(), it->path.data());
     }
   }
@@ -227,15 +237,16 @@ void KTemplateConfig::edit()
   }
 }
 
-KBackgroundConfig::KBackgroundConfig(QWidget *parent) : QWidget(parent)
+KBackgroundConfig::KBackgroundConfig( QWidget* parent )
+  : QWidget( parent )
 {
   debug("KBackgroundConfig - constructor");
-  initMetaObject();
 
   lb_ex = 0L;
 
   pprops = KIconEditProperties::getProperties(parent);
   color = pprops->backgroundcolor;
+
   pixpath = pprops->backgroundpixmap;
   pix.load(pixpath.data());
   if(pix.isNull())
@@ -245,94 +256,80 @@ KBackgroundConfig::KBackgroundConfig(QWidget *parent) : QWidget(parent)
     pix = pmlogo;
   }
 
-  QGroupBox *grp1 = new QGroupBox(i18n("Color or pixmap"), this);
+  QVBoxLayout *mainLayout = new QVBoxLayout( this, 5 );
 
-  btngrp = new QButtonGroup(grp1);
-  connect( btngrp, SIGNAL(clicked(int)), SLOT(slotBackgroundMode(int)));
-  btngrp->setExclusive(true);
-  btngrp->setFrameStyle(QFrame::NoFrame);
+  QGroupBox *grp1 = new QGroupBox( i18n( "Color or pixmap" ), this );
+  mainLayout->addWidget( grp1 );
 
-  int w = 0, h = 0;
-  QRadioButton *rbc = new QRadioButton(i18n("Colored background"), btngrp);
-  rbc->setFixedSize(rbc->sizeHint());
-  w = rbc->width();
-  h = rbc->height();
+  QGridLayout *grp1Layout = new QGridLayout( grp1, 3, 2, 15 );
 
-  QRadioButton *rbp = new QRadioButton(i18n("Pixmap background"), btngrp);
-  rbp->setFixedSize(rbp->sizeHint());
-  if(w < rbp->width())
-    w = rbp->width();
+  QButtonGroup* btngrp = new QButtonGroup( grp1 );
+  btngrp->setExclusive( true );
+  btngrp->setFrameStyle( QFrame::NoFrame );
+  connect( btngrp, SIGNAL( clicked( int ) ), SLOT( slotBackgroundMode( int ) ) );
+  grp1Layout->addWidget( btngrp, 0, 0 );
 
-  rbc->move(5, 5);
-  rbp->move(5, 10+h);
+  QVBoxLayout *bgl = new QVBoxLayout( btngrp, 5 );
 
-  btngrp->setFixedSize(w+10, 15+(2*h));
+  QRadioButton *rbc = new QRadioButton( i18n( "Colored background" ), btngrp );
+  btngrp->insert( rbc, 0 );
+  bgl->addWidget( rbc );
 
-  btngrp->insert(rbc, 0);
-  btngrp->insert(rbp, 1);
+  QRadioButton *rbp = new QRadioButton( i18n( "Pixmap background" ), btngrp );
+  btngrp->insert( rbp, 1 );
+  bgl->addWidget( rbp );
 
-  KButtonBox *bbox = new KButtonBox( grp1, KButtonBox::VERTICAL );
+  bgl->addStretch( 1 );
 
-  btcolor = bbox->addButton( i18n("&Color...") );
-  btcolor->setFixedSize(btcolor->sizeHint());
+  KButtonBox *bbox = new KButtonBox( grp1, Qt::Vertical );
+  grp1Layout->addWidget( bbox, 0, 1 );
 
-  btpix = bbox->addButton( i18n("&Pixmap...") );
-  btpix->setFixedSize(btpix->sizeHint());
+  btcolor = bbox->addButton( i18n( "&Color..." ) );
+  connect( btcolor, SIGNAL( clicked() ), SLOT( selectColor() ) );
 
-  bbox->setMaximumHeight(bbox->sizeHint().height());
+  btpix = bbox->addButton( i18n( "&Pixmap..." ) );
+  connect( btpix, SIGNAL( clicked() ), SLOT( selectPixmap() ) );
 
-  connect(btcolor, SIGNAL(clicked()), SLOT(selectColor()));
-  connect(btpix, SIGNAL(clicked()), SLOT(selectPixmap()));
+  bbox->layout();
 
-  QRadioButton *rbb = new QRadioButton(i18n("&Built-in"), grp1);
-  rbb->setFixedSize(rbb->sizeHint());
+  QRadioButton *rbb = new QRadioButton( i18n( "&Built-in" ), grp1 );
+  grp1Layout->addMultiCellWidget( rbb, 1, 1, 0, 1, AlignHCenter );
 
+  grp1Layout->setRowStretch( 2, 1 );
 
-  QGroupBox *grp2 = new QGroupBox(i18n("Example"), this);
+  QGroupBox *grp2 = new QGroupBox( i18n( "Example" ), this );
+  mainLayout->addWidget( grp2, 1 );
 
-  lb_ex = new QLabel(grp2);
-  lb_ex->setMinimumHeight((btngrp->height()/2)*3);
-  lb_ex->setFrameStyle(QFrame::Panel|QFrame::Sunken);
+  QBoxLayout *l2 = new QVBoxLayout( grp2, 15 );
 
-  QBoxLayout *ml = new QVBoxLayout(this);
+  l2->addSpacing( 10 );
 
-  QBoxLayout *l1 = new  QHBoxLayout(grp1, 20);
-  QBoxLayout *l1r = new  QVBoxLayout();
-  QBoxLayout *l2 = new  QVBoxLayout(grp2, 15);
+  lb_ex = new QLabel( grp2 );
+  lb_ex->setFrameStyle( QFrame::Panel | QFrame::Sunken );
+  l2->addWidget( lb_ex );
 
-  l1->addWidget(btngrp, 0, AlignLeft);
-  l1->addLayout(l1r);
-  l1r->addWidget(bbox, 0, AlignLeft);
-  l1r->addWidget(rbb, 0, AlignLeft);
-  l2->addWidget(lb_ex);
+/*
+  l1->addWidget( btngrp, 0, AlignLeft );
+  l1->addLayout( l1r );
+*/
 
   bgmode = pprops->backgroundmode;
-  if(bgmode == QWidget::FixedPixmap)
+  if( bgmode == QWidget::FixedPixmap )
   {
-    btngrp->setButton(1);
-    btcolor->setEnabled(false);
-    lb_ex->setBackgroundPixmap(pix);
+    btngrp->setButton( 1 );
+    btcolor->setEnabled( false );
+    lb_ex->setBackgroundPixmap( pix );
   }
   else
   {
-    btngrp->setButton(0);
-    btpix->setEnabled(false);
-    lb_ex->setBackgroundColor(color);
+    btngrp->setButton( 0 );
+    btpix->setEnabled( false );
+    lb_ex->setBackgroundColor( color );
   }
-
-  ml->addWidget(grp1);
-  ml->addWidget(grp2, 10);
-  bbox->layout();
-  l1->activate();
-  l2->activate();
-  ml->activate();
-
-  debug("KBackgroundConfig - constructor done");
 }
 
 KBackgroundConfig::~KBackgroundConfig()
 {
-
 }
 
 void KBackgroundConfig::slotBackgroundMode(int id)
@@ -377,37 +374,43 @@ void KBackgroundConfig::selectColor()
 
 void KBackgroundConfig::selectPixmap()
 {
-  QString path = KIconFileDlg::getOpenFileName("/", "*.xpm");
-  if(!path.isEmpty())
+  KURL url = KFileDialog::getOpenURL("/", "*.xpm");
+
+  if( url.isEmpty() )
+    return;
+
+  if( !url.isLocalFile() )
   {
-    QPixmap p(path.data());
-    if(!p.isNull())
-    {
-      lb_ex->setBackgroundPixmap(p);
-      pixpath = path;
-    }
+    KMessageBox::sorry( 0L, i18n( "Only local files are supported yet." ) );
+    return;
+  }
+
+  QPixmap p(url.path().data());
+
+  if( !p.isNull() )
+  {
+    lb_ex->setBackgroundPixmap( p );
+    pixpath = url.path().data();
   }
 }
 
 KToolBarConfig::KToolBarConfig(QWidget *parent) : QWidget(parent)
 {
   debug("KToolBarConfig - constructor");
-  initMetaObject();
 
   pprops = props(parent);
 
-  btngrptool = new QButtonGroup(i18n("Main Toolbar"), this);
+  QButtonGroup* btngrptool = new QButtonGroup(i18n("Main Toolbar"), this);
   btngrptool->setExclusive(true);
 
-  btngrpdraw = new QButtonGroup(i18n("Drawing tools"), this);
+  QButtonGroup* btngrpdraw = new QButtonGroup(i18n("Drawing tools"), this);
   btngrpdraw->setExclusive(true);
 
   QLabel *lb = new QLabel(
       i18n("Note: Other settings of the toolbars can be reached\n"
            "from the toolbar \"handle\" or from the \"Options\" menu"), this);
-  lb->setFixedSize(lb->sizeHint());
 
-  QBoxLayout *ml = new  QVBoxLayout(this, 10);
+  QBoxLayout *ml = new  QVBoxLayout(this, 5);
   QBoxLayout *lh = new QHBoxLayout();
 
   ml->addLayout(lh);
@@ -423,39 +426,27 @@ KToolBarConfig::KToolBarConfig(QWidget *parent) : QWidget(parent)
   l2->addSpacing(btngrptool->fontMetrics().height());
 
   rb = new QRadioButton(i18n("Show Icon"), btngrptool);
-  rb->setFixedSize(rb->sizeHint());
   l1->addWidget(rb, 0, AlignLeft);
   //connect(rbp, SIGNAL(toggled(bool)), SLOT(pasteMode(bool)));
 
   rb = new QRadioButton(i18n("Show Icon and Text"), btngrptool);
-  rb->setFixedSize(rb->sizeHint());
   l1->addWidget(rb, 0, AlignLeft);
 
   rb = new QRadioButton(i18n("Show Text"), btngrptool);
-  rb->setFixedSize(rb->sizeHint());
   l1->addWidget(rb, 0, AlignLeft);
 
   rb = new QRadioButton(i18n("Show Icon"), btngrpdraw);
-  rb->setFixedSize(rb->sizeHint());
   l2->addWidget(rb, 0, AlignLeft);
   //connect(rbp, SIGNAL(toggled(bool)), SLOT(pasteMode(bool)));
 
   rb = new QRadioButton(i18n("Show Icon and Text"), btngrpdraw);
-  rb->setFixedSize(rb->sizeHint());
   l2->addWidget(rb, 0, AlignLeft);
 
   rb = new QRadioButton(i18n("Show Text"), btngrpdraw);
-  rb->setFixedSize(rb->sizeHint());
   l2->addWidget(rb, 0, AlignLeft);
 
   ml->addStretch(1);
 
-  l1->activate();
-
-  l2->activate();
-
-  ml->activate();
-
   mstat = pprops->maintoolbartext;
   dstat = pprops->drawtoolbartext;
   btngrptool->setButton(mstat);
@@ -479,8 +470,8 @@ void KToolBarConfig::saveSettings()
   pprops->maintoolbartext = mstat;
   pprops->drawtoolbartext = dstat;
 
-  pprops->maintoolbar->setIconText(mstat);
-  pprops->drawtoolbar->setIconText(dstat);
+  pprops->maintoolbar->setIconText((KToolBar::IconText)mstat);
+  pprops->drawtoolbar->setIconText((KToolBar::IconText)dstat);
 
   debug("KToolBarConfig::saveSettings - done");
 }
@@ -498,26 +489,25 @@ void KToolBarConfig::mainToolBar(int i)
 KMiscConfig::KMiscConfig(QWidget *parent) : QWidget(parent)
 {
   debug("KMiscConfig - constructor");
-  initMetaObject();
 
   pprops = props(parent);
 
-  QGroupBox *grp1 = new QGroupBox(i18n("Paste mode"), this);
+  QBoxLayout *ml = new QVBoxLayout( this, 5 );
 
-  QRadioButton *rbp = new QRadioButton(i18n("Paste transparent pixels"), grp1);
-  rbp->setFixedSize(rbp->sizeHint());
-  connect(rbp, SIGNAL(toggled(bool)), SLOT(pasteMode(bool)));
-
-  QRadioButton *rbr = new QRadioButton(i18n("Show rulers"), grp1);
-  rbr->setFixedSize(rbr->sizeHint());
-  connect(rbr, SIGNAL(toggled(bool)), SLOT(showRulers(bool)));
-
-  QBoxLayout *ml = new QVBoxLayout(this);
+  QGroupBox *grp1 = new QGroupBox( i18n( "Paste mode" ), this );
+  ml->addWidget(grp1);
 
   QBoxLayout *l1 = new  QVBoxLayout(grp1, 20);
 
-  l1->addWidget(rbp, 0, AlignLeft);
-  l1->addWidget(rbr, 0, AlignLeft);
+  QRadioButton *rbp = new QRadioButton( i18n( "Paste transparent pixels" ), grp1 );
+  connect( rbp, SIGNAL( toggled( bool ) ), SLOT( pasteMode( bool ) ) );
+  l1->addWidget(rbp);
+
+  QRadioButton *rbr = new QRadioButton( i18n( "Show rulers" ), grp1 );
+  connect( rbr, SIGNAL( toggled( bool ) ), SLOT( showRulers( bool ) ) );
+  l1->addWidget(rbr);
+
+  l1->addStretch(1);
 
   pastemode = pprops->pastetransparent;
   if(pastemode)
@@ -526,13 +516,6 @@ KMiscConfig::KMiscConfig(QWidget *parent) : QWidget(parent)
   showrulers = pprops->showrulers;
   if(showrulers)
     rbr->setChecked(true);
-
-  ml->addWidget(grp1);
-  ml->addStretch(1);
-  l1->activate();
-  ml->activate();
-
-  debug("KMiscConfig - constructor done");
 }
 
 KMiscConfig::~KMiscConfig()
@@ -543,9 +526,9 @@ KMiscConfig::~KMiscConfig()
 void KMiscConfig::saveSettings()
 {
   debug("KMiscConfig::saveSettings");
+
   pprops->pastetransparent = pastemode;
   pprops->showrulers = showrulers;
-  debug("KMiscConfig::saveSettings - done");
 }
 
 void KMiscConfig::pasteMode(bool mode)
@@ -558,12 +541,14 @@ void KMiscConfig::showRulers(bool mode)
   showrulers = mode;
 }
 
-KIconConfig::KIconConfig(QWidget *parent) : KNoteBook(parent, 0, true)
+KIconConfig::KIconConfig(QWidget *parent)
+  : QTabDialog(parent, 0, true)
 {
+  setCaption( "Configure" );
+  setCancelButton();
+  connect( this, SIGNAL( applyButtonPressed() ), SLOT( saveSettings() ) );
+
   pprops = KIconEditProperties::getProperties(parent);
-  debug("KIconConfig - constructor");
-  initMetaObject();
-  setCaption("Configure ");
   //keys = k; //new KAccel(parent);
   //dict = new QDict<KKeyEntry>( k->keyDict() );
   //debug("Keys: %u", k->keyDict().count());
@@ -572,80 +557,20 @@ KIconConfig::KIconConfig(QWidget *parent) : KNoteBook(parent, 0, true)
   pprops->keydict = pprops->keys->keyDict();
   debug("Keys: %u", pprops->keydict.count());
 
-  setCancelButton();
-  setOkButton();
-  //setDirectionsReflectsPage(true);
-  setEnablePopupMenu(true);
-  setEnableArrowButtons(true);
-
-  debug("KIconConfig - constructor");
-
-  keychooser = new KKeyChooser(&pprops->keydict, this);
-  debug("KeyChooser created");
-  keychooser->setMinimumSize(300, 275);
-
-  debug("KIconConfig - constructor");
-
-  connect( this, SIGNAL(cancelclicked()), SLOT(reject()) );
-  connect( this, SIGNAL(okclicked()), SLOT(saveSettings()) );
-
-  QTab *tab = new QTab;            // create a QTab to hold the tab data
-  tab->label = i18n("Keys");
-  tab->enabled = true;
-  addTab( tab );
-  KWizardPage *p = new KWizardPage;
-  p->w = keychooser;
-  p->title = i18n("Configure keys");
-  p->enabled = true;
-  addPage( p );
+  keychooser = new KKeyChooser( &pprops->keydict, this );
+  addTab( keychooser, i18n( "Keys" ) );
 
   temps = new KTemplateConfig(this);
-
-  tab = new QTab;            // create a QTab to hold the tab data
-  tab->label = i18n("Templates");
-  tab->enabled = true;
-  addTab( tab );
-  p = new KWizardPage;
-  p->w = temps;
-  p->title = i18n("Configure Icon templates");
-  p->enabled = true;
-  addPage( p );
+  addTab( temps, i18n( "Icon templates" ) );
 
   backs = new KBackgroundConfig(this);
+  addTab( backs, i18n( "Background" ) );
 
-  tab = new QTab;            // create a QTab to hold the tab data
-  tab->label = i18n("Appearance");
-  tab->enabled = true;
-  addTab( tab );
-  p = new KWizardPage;
-  p->w = backs;
-  p->title = i18n("Configure background");
-  p->enabled = true;
-  addPage( p );
+  toolbars = new KToolBarConfig( this );
+  addTab( toolbars, i18n( "Toolbars" ) );
 
-  toolbars = new KToolBarConfig(this);
-
-  p = new KWizardPage;
-  p->w = toolbars;
-  p->title = i18n("Toolbars");
-  p->enabled = true;
-  addPage( p );
-
-  misc = new KMiscConfig(this);
-
-  tab = new QTab;            // create a QTab to hold the tab data
-  tab->label = i18n("Miscellaneous");
-  tab->enabled = true;
-  addTab( tab );
-  p = new KWizardPage;
-  p->w = misc;
-  p->title = i18n("Icon grid");
-  p->enabled = true;
-  addPage( p );
-
-  setSizes();
-
-  debug("KIconConfig - constructor - done");
+  misc = new KMiscConfig( this );
+  addTab( misc, i18n( "Icon grid" ) );
 }
 
 KIconConfig::~KIconConfig()
@@ -657,14 +582,10 @@ void KIconConfig::saveSettings()
 {
   debug("KIconEditConfig::saveSettings");
 
-  pprops->keys->setKeyDict(pprops->keydict);
-  debug("KIconEditConfig::saveSettings - keys saved");
+  pprops->keys->setKeyDict( pprops->keydict );
   temps->saveSettings();
   backs->saveSettings();
   misc->saveSettings();
   toolbars->saveSettings();
-  debug("KIconEditConfig::saveSettings - done");
   accept();
 }
-
-
