@@ -20,8 +20,13 @@
 
 #include <qwhatsthis.h>
 #include <qtooltip.h>
+
+#include <kconfig.h>
 #include <kruler.h>
-#include "debug.h"
+#include <klocale.h>
+#include <kmessagebox.h>
+#include <ktoolbarbutton.h>
+
 #include "kiconedit.h"
 #include "kdragsource.h"
 #include "main.h"
@@ -36,7 +41,7 @@ KIconEdit::KIconEdit(const QImage image, const char *name)
   preview->setPixmap(grid->pixmap());
 }
 
-KIconEdit::KIconEdit(const char *xpm, const char *name)
+KIconEdit::KIconEdit(const QString &xpm, const char *name)
  : KTMainWindow(name)
 {
   init();
@@ -46,18 +51,11 @@ KIconEdit::KIconEdit(const char *xpm, const char *name)
 
 void KIconEdit::init()
 {
-  initMetaObject();
-  setCaption(kapp->getCaption());
+  setCaption(kapp->caption());
 
   printer = new QPrinter;
   CHECK_PTR(printer);
 
-  if(!windowList)
-  {
-    debug("KIconEdit::KIconEdit() Globalizing windowlist");
-    windowList = (WindowList*)memberList;
-  }
-
   kiprops = new KIconEditProperties(this);
   CHECK_PTR(kiprops);
   Properties *pprops = props(this);
@@ -73,11 +71,8 @@ void KIconEdit::init()
   CHECK_PTR(msgtimer);
   connect( msgtimer, SIGNAL(timeout()), SLOT(slotClearStatusMessage()));
 
-#ifdef KWIZARD_VERSION
   icontemplates = new KIconTemplateContainer;
   CHECK_PTR(icontemplates);
-  debug("Templates created");
-#endif
 
   gridview = new KGridView(&img, this); //viewport->viewport()); //KIconEditView(this);
   CHECK_PTR(gridview);
@@ -85,19 +80,13 @@ void KIconEdit::init()
 
   grid = gridview->grid();
 
-  debug("Grid created");
   grid->setGrid(pprops->showgrid);
-  debug("Grid->setGrid done");
   grid->setCellSize(pprops->gridscaling);
-  debug("Grid->setCellSize done");
 
-  icon = new KIcon(this, &grid->image());
+  icon = new KIconEditIcon(this, &grid->image());
   CHECK_PTR(icon);
 
-  dropzone = new KDNDDropZone( grid, DndURL);
-  CHECK_PTR(dropzone);
-  connect( dropzone, SIGNAL( dropAction( KDNDDropZone *) ), 
-    this, SLOT( slotDropEvent( KDNDDropZone *) ) );
+  setAcceptDrops(true);
 
   dropsite = new KDropSite( grid );
   CHECK_PTR(dropsite);
@@ -179,7 +168,6 @@ void KIconEdit::init()
 
 KIconEdit::~KIconEdit()
 {
-  debug("KIconEdit - Destructor");
 /*  the following should be destructed by the QObject/QWidget destructor
     if(l)
       delete l;
@@ -211,11 +199,9 @@ KIconEdit::~KIconEdit()
     if(statusbar)
       delete statusbar;
     statusbar = 0L; 
-#ifdef KWIZARD_VERSION
     if(icontemplates)
       delete icontemplates;
     icontemplates = 0L;
-#endif 
     delete file;
     delete edit;
     delete view;
@@ -225,27 +211,25 @@ KIconEdit::~KIconEdit()
     delete select;
     delete recent;
     delete zoom;
-
-  debug("KIconEdit - Destructor: done");
 }
 
-void KIconEdit::closeEvent(QCloseEvent *e)
+bool KIconEdit::queryClose()
 {
   bool cancel = false;
   if (grid->isModified()) 
   {
-    KWM::activate(winId());
-    int r = KMsgBox::yesNoCancel(this, i18n("Warning"),
+    //KWM::activate(winId());
+    int r = KMessageBox::warningYesNoCancel(this,
 		i18n("The current file has been modified.\nDo you want to save it?"));
     switch(r)
     {
-      case 1:
+      case 0:
         icon->save(&grid->image());
         //grid->save(grid->drawPath());
         break;
-      case 2:
+      case 1:
         break;
-      case 3:
+      case 2:
         cancel = true;
         break;
       default:
@@ -256,16 +240,8 @@ void KIconEdit::closeEvent(QCloseEvent *e)
   {
     writeConfig();
     icon->cleanup();
-    e->accept();
-    delete this;
-    if(memberList->count() == 0)
-    {
-      debug("KIconEdit: Last in list closes the door...");
-      kapp->quit();
-    }
   }
-  else
-    e->ignore();
+  return (!cancel);
 }
 
 void KIconEdit::resizeEvent( QResizeEvent * )
@@ -279,9 +255,10 @@ void KIconEdit::resizeEvent( QResizeEvent * )
   //viewport->updateScrollBars();
 }
 
-void KIconEdit::unsaved(bool flag)
+void KIconEdit::unsaved( bool /*flag*/ )
 {
-    setUnsavedData(flag);
+#warning fix session management
+    //setUnsavedData(flag);
 }
 
 void KIconEdit::saveGoingDownStatus()
@@ -327,7 +304,6 @@ void KIconEdit::writeConfig()
 
   pprops->maintoolbarpos = toolbar->barPos();
   pprops->drawtoolbarpos = drawtoolbar->barPos();
-  pprops->menubarpos = menubar->menuBarPos();
 
   //pprops->showgrid = grid->hasGrid();
   //pprops->gridscaling = grid->cellSize();
@@ -361,15 +337,15 @@ bool KIconEdit::setupMenuBar()
   KAccel *keys = pprops->keys; // = new KAccel( this ); 
   CHECK_PTR(keys);
 
-  keys->connectItem( KAccel::New, this, SLOT(slotNew()) );
-  keys->connectItem( KAccel::Save , this, SLOT(slotSave()) );
-  keys->connectItem( KAccel::Quit, this, SLOT(slotQuit()) );
-  keys->connectItem( KAccel::Cut , this, SLOT(slotCut()) );
-  keys->connectItem( KAccel::Copy , this, SLOT(slotCopy()) );
-  keys->connectItem( KAccel::Paste , this, SLOT(slotPaste()) );
-  keys->connectItem( KAccel::Open , this, SLOT(slotOpen()) );
-  keys->connectItem( KAccel::Close , this, SLOT(slotClose()) );
-  keys->connectItem( KAccel::Print , this, SLOT(slotPrint()) );
+  keys->connectItem( KStdAccel::New, this, SLOT(slotNew()) );
+  keys->connectItem( KStdAccel::Save , this, SLOT(slotSave()) );
+  keys->connectItem( KStdAccel::Quit, this, SLOT(slotQuit()) );
+  keys->connectItem( KStdAccel::Cut , this, SLOT(slotCut()) );
+  keys->connectItem( KStdAccel::Copy , this, SLOT(slotCopy()) );
+  keys->connectItem( KStdAccel::Paste , this, SLOT(slotPaste()) );
+  keys->connectItem( KStdAccel::Open , this, SLOT(slotOpen()) );
+  keys->connectItem( KStdAccel::Close , this, SLOT(slotClose()) );
+  keys->connectItem( KStdAccel::Print , this, SLOT(slotPrint()) );
   keys->insertItem(i18n("Select All"),   "Select All",   CTRL+Key_A);
   keys->connectItem( "Select All", this, SLOT(slotSelectAll()) );
   keys->readSettings();
@@ -388,15 +364,15 @@ bool KIconEdit::setupMenuBar()
   file = new QPopupMenu;
   CHECK_PTR(file);
 
-  file->insertItem(Icon("newwin.xpm"), i18n("New &Window"), ID_FILE_NEWWIN);
+  file->insertItem(BarIcon("newwin"), i18n("New &Window"), ID_FILE_NEWWIN);
   file->connectItem(ID_FILE_NEWWIN, this, SLOT(slotNewWin()));
 
   file->insertSeparator();
 
-  id = file->insertItem(Icon("filenew.xpm"), i18n("&New..."), ID_FILE_NEWFILE);
+  id = file->insertItem(BarIcon("filenew"), i18n("&New..."), ID_FILE_NEWFILE);
   file->connectItem(ID_FILE_NEWFILE, this, SLOT(slotNew()));
 
-  id = file->insertItem(Icon("fileopen.xpm"), i18n("&Open..."), ID_FILE_OPEN);
+  id = file->insertItem(BarIcon("fileopen"), i18n("&Open..."), ID_FILE_OPEN);
   file->connectItem(ID_FILE_OPEN, this, SLOT(slotOpen()));
 
   file->insertItem(i18n("Open recent"), recent, ID_FILE_RECENT);
@@ -404,7 +380,7 @@ bool KIconEdit::setupMenuBar()
 
   file->insertSeparator();
 
-  id = file->insertItem(Icon("filefloppy.xpm"), i18n("&Save"), ID_FILE_SAVE);
+  id = file->insertItem(BarIcon("filefloppy"), i18n("&Save"), ID_FILE_SAVE);
   file->connectItem(ID_FILE_SAVE, this, SLOT(slotSave()));
 
   file->insertItem(i18n("S&ave as..."), ID_FILE_SAVEAS);
@@ -412,12 +388,12 @@ bool KIconEdit::setupMenuBar()
 
   file->insertSeparator();
 
-  id = file->insertItem(Icon("fileprint.xpm"), i18n("&Print..."), ID_FILE_PRINT);
+  id = file->insertItem(BarIcon("fileprint"), i18n("&Print..."), ID_FILE_PRINT);
   file->connectItem(ID_FILE_PRINT, this, SLOT(slotPrint()));
 
   file->insertSeparator();
 
-  id = file->insertItem(Icon("fileclose.xpm"), i18n("&Close"), ID_FILE_CLOSE);
+  id = file->insertItem(BarIcon("fileclose"), i18n("&Close"), ID_FILE_CLOSE);
   file->connectItem(ID_FILE_CLOSE, this, SLOT(slotClose()));
 
   id = file->insertItem(i18n("&Exit"), ID_FILE_QUIT);
@@ -428,13 +404,13 @@ bool KIconEdit::setupMenuBar()
   edit = new QPopupMenu;
   CHECK_PTR(edit);
 
-  id = edit->insertItem(Icon("editcut.xpm"), i18n("Cu&t"), ID_EDIT_CUT);
+  id = edit->insertItem(BarIcon("editcut"), i18n("Cu&t"), ID_EDIT_CUT);
   edit->connectItem(ID_EDIT_CUT, this, SLOT(slotCut()));
 
-  id = edit->insertItem(Icon("editcopy.xpm"), i18n("&Copy"), ID_EDIT_COPY);
+  id = edit->insertItem(BarIcon("editcopy"), i18n("&Copy"), ID_EDIT_COPY);
   edit->connectItem(ID_EDIT_COPY, this, SLOT(slotCopy()));
 
-  id = edit->insertItem(Icon("editpaste.xpm"), i18n("&Paste"), ID_EDIT_PASTE);
+  id = edit->insertItem(BarIcon("editpaste"), i18n("&Paste"), ID_EDIT_PASTE);
   edit->connectItem(ID_EDIT_PASTE, this, SLOT(slotPaste()));
 
   id = edit->insertItem(i18n("Paste as &new"), ID_EDIT_PASTE_AS_NEW);
@@ -458,37 +434,37 @@ bool KIconEdit::setupMenuBar()
 
   view = new QPopupMenu;
   CHECK_PTR(view);
-  id = view->insertItem(Icon("viewmag+.xpm"), i18n("Zoom &in"), ID_VIEW_ZOOM_IN);
-  id = view->insertItem(Icon("viewmag-.xpm"), i18n("Zoom &out"), ID_VIEW_ZOOM_OUT);
-  id = view->insertItem(Icon("viewmag.xpm"), i18n("Zoom factor"), zoom);
+  id = view->insertItem(BarIcon("viewmag+"), i18n("Zoom &in"), ID_VIEW_ZOOM_IN);
+  id = view->insertItem(BarIcon("viewmag-"), i18n("Zoom &out"), ID_VIEW_ZOOM_OUT);
+  id = view->insertItem(BarIcon("viewmag"), i18n("Zoom factor"), zoom);
   connect( view, SIGNAL(activated(int)), SLOT(slotView(int)));
   menubar->insertItem(i18n("&View"), view);
 
   image = new QPopupMenu;
   CHECK_PTR(image);
 #if QT_VERSION >= 140
-  id = image->insertItem(Icon("transform.xpm"), i18n("&Resize"), ID_IMAGE_RESIZE);
+  id = image->insertItem(BarIcon("transform"), i18n("&Resize"), ID_IMAGE_RESIZE);
 #endif
-  id = image->insertItem(Icon("grayscale.xpm"), i18n("&GrayScale"), ID_IMAGE_GRAYSCALE);
+  id = image->insertItem(BarIcon("grayscale"), i18n("&GrayScale"), ID_IMAGE_GRAYSCALE);
   
-  //id = image->insertItem(Icon("kdepalette.xpm"), i18n("&Map to KDE palette"), ID_IMAGE_MAPTOKDE);
+  //id = image->insertItem(BarIcon("kdepalette"), i18n("&Map to KDE palette"), ID_IMAGE_MAPTOKDE);
   
   connect( image, SIGNAL(activated(int)), SLOT(slotImage(int)));
   menubar->insertItem(i18n("&Icon"), image);
 
   tools = new QPopupMenu;
   CHECK_PTR(tools);
-  tools->insertItem(Icon("paintbrush.xpm"), i18n("Freehand"), ID_DRAW_FREEHAND);
-  tools->insertItem(Icon("rectangle.xpm"), i18n("Rectangle"), ID_DRAW_RECT);
-  tools->insertItem(Icon("filledrectangle.xpm"), i18n("Filled rectangle"), ID_DRAW_RECT_FILL);
-  tools->insertItem(Icon("circle.xpm"), i18n("Circle"), ID_DRAW_CIRCLE);
-  tools->insertItem(Icon("filledcircle.xpm"), i18n("Filled circle"), ID_DRAW_CIRCLE_FILL);
-  tools->insertItem(Icon("ellipse.xpm"), i18n("Ellipse"), ID_DRAW_ELLIPSE);
-  tools->insertItem(Icon("filledellipse.xpm"), i18n("Filled ellipse"), ID_DRAW_ELLIPSE_FILL);
-  tools->insertItem(Icon("spraycan.xpm"), i18n("Spray"), ID_DRAW_SPRAY);
-  tools->insertItem(Icon("flood.xpm"), i18n("Flood fill"), ID_DRAW_FILL);
-  tools->insertItem(Icon("line.xpm"), i18n("Line"), ID_DRAW_LINE);
-  tools->insertItem(Icon("eraser.xpm"), i18n("Eraser (Transparent)"), ID_DRAW_ERASE);
+  tools->insertItem(BarIcon("paintbrush"), i18n("Freehand"), ID_DRAW_FREEHAND);
+  tools->insertItem(BarIcon("rectangle"), i18n("Rectangle"), ID_DRAW_RECT);
+  tools->insertItem(BarIcon("filledrectangle"), i18n("Filled rectangle"), ID_DRAW_RECT_FILL);
+  tools->insertItem(BarIcon("circle"), i18n("Circle"), ID_DRAW_CIRCLE);
+  tools->insertItem(BarIcon("filledcircle"), i18n("Filled circle"), ID_DRAW_CIRCLE_FILL);
+  tools->insertItem(BarIcon("ellipse"), i18n("Ellipse"), ID_DRAW_ELLIPSE);
+  tools->insertItem(BarIcon("filledellipse"), i18n("Filled ellipse"), ID_DRAW_ELLIPSE_FILL);
+  tools->insertItem(BarIcon("spraycan"), i18n("Spray"), ID_DRAW_SPRAY);
+  tools->insertItem(BarIcon("flood"), i18n("Flood fill"), ID_DRAW_FILL);
+  tools->insertItem(BarIcon("line"), i18n("Line"), ID_DRAW_LINE);
+  tools->insertItem(BarIcon("eraser"), i18n("Eraser (Transparent)"), ID_DRAW_ERASE);
   //tools->insertSeparator();
   connect( tools, SIGNAL(activated(int)), SLOT(slotTools(int)));
   menubar->insertItem(i18n("&Tools"), tools);
@@ -510,7 +486,7 @@ bool KIconEdit::setupMenuBar()
   if(pprops->statusbarstat)
     options->setItemChecked(ID_OPTIONS_TOGGLE_STATS, true);
   options->insertSeparator();
-  options->insertItem(Icon("filefloppy.xpm"), i18n("&Save options"), ID_OPTIONS_SAVE);
+  options->insertItem(BarIcon("filefloppy"), i18n("&Save options"), ID_OPTIONS_SAVE);
   connect( options, SIGNAL(activated(int)), SLOT(slotConfigure(int)));
   menubar->insertItem(i18n("&Options"), options);
 
@@ -524,10 +500,9 @@ bool KIconEdit::setupMenuBar()
                      "tanghus@kde.org\n"
                      "http://w1.1358.telia.com/~u135800018"));
 
-  help = kapp->getHelpMenu(true,about.data());
+  help = helpMenu(about.data());
   menubar->insertItem(i18n("&Help"), help);
 
-  menubar->setMenuBarPos(pprops->menubarpos);
   updateMenuAccel();
   menubar->show();
   //connect( menubar, SIGNAL(activated(int)), SLOT(slotActions(int)));
@@ -541,16 +516,16 @@ void KIconEdit::updateMenuAccel()
   KAccel *keys = props(this)->keys; // = new KAccel( this ); 
   CHECK_PTR(keys);
 
-  keys->changeMenuAccel(file, ID_FILE_NEWFILE, KAccel::New); 
-  keys->changeMenuAccel(file, ID_FILE_OPEN, KAccel::Open); 
-  keys->changeMenuAccel(file, ID_FILE_SAVE, KAccel::Save); 
-  keys->changeMenuAccel(file, ID_FILE_PRINT, KAccel::Print); 
-  keys->changeMenuAccel(file, ID_FILE_CLOSE, KAccel::Close); 
-  keys->changeMenuAccel(file, ID_FILE_QUIT, KAccel::Quit); 
+  keys->changeMenuAccel(file, ID_FILE_NEWFILE, KStdAccel::New); 
+  keys->changeMenuAccel(file, ID_FILE_OPEN, KStdAccel::Open); 
+  keys->changeMenuAccel(file, ID_FILE_SAVE, KStdAccel::Save); 
+  keys->changeMenuAccel(file, ID_FILE_PRINT, KStdAccel::Print); 
+  keys->changeMenuAccel(file, ID_FILE_CLOSE, KStdAccel::Close); 
+  keys->changeMenuAccel(file, ID_FILE_QUIT, KStdAccel::Quit); 
 
-  keys->changeMenuAccel(edit, ID_EDIT_CUT, KAccel::Cut); 
-  keys->changeMenuAccel(edit, ID_EDIT_COPY, KAccel::Copy); 
-  keys->changeMenuAccel(edit, ID_EDIT_PASTE, KAccel::Paste); 
+  keys->changeMenuAccel(edit, ID_EDIT_CUT, KStdAccel::Cut); 
+  keys->changeMenuAccel(edit, ID_EDIT_COPY, KStdAccel::Copy); 
+  keys->changeMenuAccel(edit, ID_EDIT_PASTE, KStdAccel::Paste); 
   keys->changeMenuAccel(edit, ID_EDIT_SELECT_ALL, "Select All"); 
 
 }
@@ -565,67 +540,62 @@ bool KIconEdit::setupToolBar()
   addToolBar(toolbar);
   pprops->maintoolbar = toolbar;
 
-  what = new QWhatsThis;
   QWidget *btwhat = (QWidget*)what->whatsThisButton(toolbar);
+  what = new QWhatsThis(btwhat);
   QToolTip::add(btwhat, i18n("What is ...?"));
 
-  QImage i;
-  QPixmap p(Icon("image.xpm"));
-  i = p;
-  i = i.smoothScale(20, 20);
-  p = i;
   dragbutton = new KDragSource("image/x-xpm", grid, SLOT(getImage(QImage*)), toolbar);
-  dragbutton->setPixmap(p);
+  dragbutton->setPixmap(BarIcon("image"));
   QToolTip::add(dragbutton, i18n("Drag source"));
 
   toolbar->insertWidget(-1, 22, dragbutton);
   toolbar->insertSeparator();
-  toolbar->insertButton(Icon("filenew.xpm"), ID_FILE_NEWFILE,
+  toolbar->insertButton(BarIcon("filenew"), ID_FILE_NEWFILE,
          SIGNAL(clicked()), this, SLOT(slotNew()), TRUE, i18n("New File"));
-  toolbar->insertButton(Icon("fileopen.xpm"),ID_FILE_OPEN,
+  toolbar->insertButton(BarIcon("fileopen"),ID_FILE_OPEN,
          SIGNAL(clicked()), this, SLOT(slotOpen()), TRUE, i18n("Open a file"));
-  toolbar->insertButton(Icon("filefloppy.xpm"), ID_FILE_SAVE,
+  toolbar->insertButton(BarIcon("filefloppy"), ID_FILE_SAVE,
          SIGNAL(clicked()), this, SLOT(slotSave()), TRUE, i18n("Save the file"));
   toolbar->insertSeparator();
-  toolbar->insertButton(Icon("fileprint.xpm"),ID_FILE_PRINT,
+  toolbar->insertButton(BarIcon("fileprint"),ID_FILE_PRINT,
          SIGNAL(clicked()), this, SLOT(slotPrint()), TRUE, i18n("Print icon"));
   toolbar->insertSeparator();
-  toolbar->insertButton(Icon("editcut.xpm"),ID_EDIT_CUT,
+  toolbar->insertButton(BarIcon("editcut"),ID_EDIT_CUT,
          SIGNAL(clicked()), this, SLOT(slotCut()), TRUE, i18n("Cut"));
-  toolbar->insertButton(Icon("editcopy.xpm"),ID_EDIT_COPY,
+  toolbar->insertButton(BarIcon("editcopy"),ID_EDIT_COPY,
          SIGNAL(clicked()), this, SLOT(slotCopy()), TRUE, i18n("Copy"));
-  toolbar->insertButton(Icon("editpaste.xpm"),ID_EDIT_PASTE,
+  toolbar->insertButton(BarIcon("editpaste"),ID_EDIT_PASTE,
          SIGNAL(clicked()), this, SLOT(slotPaste()), TRUE, i18n("Paste"));
 
   select = new QPopupMenu;
   CHECK_PTR(select);
-  select->insertItem(Icon("selectrect.xpm"), ID_SELECT_RECT);
-  select->insertItem(Icon("selectcircle.xpm"), ID_SELECT_CIRCLE);
+  select->insertItem(BarIcon("selectrect"), ID_SELECT_RECT);
+  select->insertItem(BarIcon("selectcircle"), ID_SELECT_CIRCLE);
   connect( select, SIGNAL(activated(int)), SLOT(slotTools(int)));
 
-  toolbar->insertButton(Icon("areaselect.xpm"), ID_SELECT, select, true, i18n("Select area"));
+  toolbar->insertButton(BarIcon("areaselect"), ID_SELECT, select, true, i18n("Select area"));
   //drawtoolbar->setToggle(ID_DRAW_SELECT, true);
 
   toolbar->insertSeparator();
 #if QT_VERSION >= 140
-  toolbar->insertButton(Icon("transform.xpm"),ID_IMAGE_RESIZE, TRUE, 
+  toolbar->insertButton(BarIcon("transform"),ID_IMAGE_RESIZE, TRUE, 
 			  i18n("Resize"));
 #endif
-  toolbar->insertButton(Icon("grayscale.xpm"),ID_IMAGE_GRAYSCALE, TRUE, 
+  toolbar->insertButton(BarIcon("grayscale"),ID_IMAGE_GRAYSCALE, TRUE, 
 			  i18n("GrayScale"));
 /*
-  toolbar->insertButton(Icon("kdepalette.xpm"),ID_IMAGE_MAPTOKDE, TRUE, 
+  toolbar->insertButton(BarIcon("kdepalette"),ID_IMAGE_MAPTOKDE, TRUE, 
 			  i18n("To KDE palette"));
 */
   toolbar->insertSeparator();
-  toolbar->insertButton(Icon("viewmag-.xpm"),ID_VIEW_ZOOM_OUT, TRUE, 
+  toolbar->insertButton(BarIcon("viewmag-"),ID_VIEW_ZOOM_OUT, TRUE, 
 			  i18n("Zoom out"));
   toolbar->setDelayedPopup(ID_VIEW_ZOOM_OUT, zoom);
-  toolbar->insertButton(Icon("viewmag+.xpm"),ID_VIEW_ZOOM_IN, TRUE, 
+  toolbar->insertButton(BarIcon("viewmag+"),ID_VIEW_ZOOM_IN, TRUE, 
 			  i18n("Zoom in"));
   toolbar->setDelayedPopup(ID_VIEW_ZOOM_IN, zoom);
   toolbar->insertSeparator();
-  toolbar->insertButton(Icon("grid.xpm"),ID_OPTIONS_TOGGLE_GRID, TRUE, 
+  toolbar->insertButton(BarIcon("grid"),ID_OPTIONS_TOGGLE_GRID, TRUE, 
 			  i18n("Toggle grid"));
   toolbar->setToggle(ID_OPTIONS_TOGGLE_GRID, true);
   if(pprops->showgrid)
@@ -635,12 +605,12 @@ bool KIconEdit::setupToolBar()
 
   toolbar->insertWidget(ID_HELP_WHATSTHIS, btwhat->sizeHint().width(), btwhat);
 
-  toolbar->insertButton(Icon("newwin.xpm"),ID_FILE_NEWWIN,
+  toolbar->insertButton(BarIcon("newwin"),ID_FILE_NEWWIN,
          SIGNAL(clicked()), this, SLOT(slotNewWin()), TRUE,
                           i18n("New Window"));
   toolbar->alignItemRight( ID_FILE_NEWWIN, true);
     
-  toolbar->setIconText(pprops->maintoolbartext);
+  toolbar->setIconText((KToolBar::IconText) pprops->maintoolbartext);
   toolbar->setBarPos(pprops->maintoolbarpos);
   if(pprops->maintoolbarstat)
     toolbar->enable(KToolBar::Show);
@@ -663,36 +633,36 @@ bool KIconEdit::setupDrawToolBar()
   CHECK_PTR(drawtoolbar);
   addToolBar(drawtoolbar);
   pprops->drawtoolbar = drawtoolbar;
-  drawtoolbar->setFullWidth();
+  drawtoolbar->setFullSize();
 
-  drawtoolbar->insertButton(Icon("pointer.xpm"), ID_DRAW_FIND, TRUE, i18n("Find pixel"));
+  drawtoolbar->insertButton(BarIcon("pointer"), ID_DRAW_FIND, TRUE, i18n("Find pixel"));
   drawtoolbar->setToggle(ID_DRAW_FIND, true);
-  drawtoolbar->insertButton(Icon("paintbrush.xpm"), ID_DRAW_FREEHAND, TRUE, i18n("Draw freehand"));
+  drawtoolbar->insertButton(BarIcon("paintbrush"), ID_DRAW_FREEHAND, TRUE, i18n("Draw freehand"));
   drawtoolbar->setToggle(ID_DRAW_FREEHAND, true);
 
-  drawtoolbar->insertButton(Icon("line.xpm"), ID_DRAW_LINE, TRUE, i18n("Draw line"));
+  drawtoolbar->insertButton(BarIcon("line"), ID_DRAW_LINE, TRUE, i18n("Draw line"));
   drawtoolbar->setToggle(ID_DRAW_LINE, true);
-  drawtoolbar->insertButton(Icon("rectangle.xpm"),ID_DRAW_RECT, TRUE, i18n("Draw rectangle"));
+  drawtoolbar->insertButton(BarIcon("rectangle"),ID_DRAW_RECT, TRUE, i18n("Draw rectangle"));
   drawtoolbar->setToggle(ID_DRAW_RECT, true);
-  drawtoolbar->insertButton(Icon("filledrectangle.xpm"),ID_DRAW_RECT_FILL, TRUE, i18n("Draw filled rectangle"));
+  drawtoolbar->insertButton(BarIcon("filledrectangle"),ID_DRAW_RECT_FILL, TRUE, i18n("Draw filled rectangle"));
   drawtoolbar->setToggle(ID_DRAW_RECT_FILL, true);
-  drawtoolbar->insertButton(Icon("circle.xpm"),ID_DRAW_CIRCLE, TRUE, i18n("Draw circle"));
+  drawtoolbar->insertButton(BarIcon("circle"),ID_DRAW_CIRCLE, TRUE, i18n("Draw circle"));
   drawtoolbar->setToggle(ID_DRAW_CIRCLE, true);
-  drawtoolbar->insertButton(Icon("filledcircle.xpm"),ID_DRAW_CIRCLE_FILL, TRUE, i18n("Draw filled circle"));
+  drawtoolbar->insertButton(BarIcon("filledcircle"),ID_DRAW_CIRCLE_FILL, TRUE, i18n("Draw filled circle"));
   drawtoolbar->setToggle(ID_DRAW_CIRCLE_FILL, true);
-  drawtoolbar->insertButton(Icon("ellipse.xpm"),ID_DRAW_ELLIPSE, TRUE, i18n("Draw ellipse"));
+  drawtoolbar->insertButton(BarIcon("ellipse"),ID_DRAW_ELLIPSE, TRUE, i18n("Draw ellipse"));
   drawtoolbar->setToggle(ID_DRAW_ELLIPSE, true);
-  drawtoolbar->insertButton(Icon("filledellipse.xpm"),ID_DRAW_ELLIPSE_FILL, TRUE, i18n("Draw filled ellipse"));
+  drawtoolbar->insertButton(BarIcon("filledellipse"),ID_DRAW_ELLIPSE_FILL, TRUE, i18n("Draw filled ellipse"));
   drawtoolbar->setToggle(ID_DRAW_ELLIPSE_FILL, true);
-  drawtoolbar->insertButton(Icon("spraycan.xpm"),ID_DRAW_SPRAY, TRUE, i18n("Spray"));
+  drawtoolbar->insertButton(BarIcon("spraycan"),ID_DRAW_SPRAY, TRUE, i18n("Spray"));
   drawtoolbar->setToggle(ID_DRAW_SPRAY, true);
-  drawtoolbar->insertButton(Icon("flood.xpm"),ID_DRAW_FILL, TRUE, i18n("Flood fill"));
+  drawtoolbar->insertButton(BarIcon("flood"),ID_DRAW_FILL, TRUE, i18n("Flood fill"));
   drawtoolbar->setToggle(ID_DRAW_FILL, true);
   drawtoolbar->setToggle(ID_DRAW_SPRAY, true);
-  drawtoolbar->insertButton(Icon("eraser.xpm"),ID_DRAW_ERASE, TRUE, i18n("Erase"));
+  drawtoolbar->insertButton(BarIcon("eraser"),ID_DRAW_ERASE, TRUE, i18n("Erase"));
   drawtoolbar->setToggle(ID_DRAW_ERASE, true);
     
-  drawtoolbar->setIconText(pprops->drawtoolbartext);
+  drawtoolbar->setIconText((KToolBar::IconText) pprops->drawtoolbartext);
   drawtoolbar->setBarPos(pprops->drawtoolbarpos);
   if(pprops->drawtoolbarstat)
     drawtoolbar->enable(KToolBar::Show);
@@ -707,18 +677,16 @@ bool KIconEdit::setupDrawToolBar()
 
 bool KIconEdit::setupPaletteToolBar()
 {
-  debug("setupPaletteToolBar");
   //Properties *pprops = props(this);
 
   QWidget *w = new QWidget(this);
   QBoxLayout *ml = new QVBoxLayout(w);
   QLabel *l = new QLabel(i18n("System Colors"), w);
-  l->setFixedSize(l->sizeHint());
+  //l->setFixedSize(l->sizeHint());
   syscolors = new KSysColors(w);
-  syscolors->setFixedSize(syscolors->width(), syscolors->height());
+  //syscolors->setFixedSize(syscolors->width(), syscolors->height());
   ml->addWidget(l);
   ml->addWidget(syscolors);
-  ml->activate();
 
   int ow = w->sizeHint().width();
   int iw = syscolors->width();
@@ -733,7 +701,7 @@ bool KIconEdit::setupPaletteToolBar()
 
   preview = new Preview(palettetoolbar);
   preview->setFrameStyle(QFrame::Panel|QFrame::Sunken);
-  preview->setFixedSize(iw, 60);
+  //preview->setFixedSize(iw, 60);
 
   palettetoolbar->insertWidget(ID_PREVIEW, iw, preview);
   palettetoolbar->insertSeparator();
@@ -743,12 +711,11 @@ bool KIconEdit::setupPaletteToolBar()
   w = new QWidget(palettetoolbar);
   ml = new QVBoxLayout(w);
   l = new QLabel(i18n("Custom Colors"), w);
-  l->setFixedSize(l->sizeHint());
+  //l->setFixedSize(l->sizeHint());
   customcolors = new KCustomColors(w);
-  customcolors->setFixedSize(iw, customcolors->height());
+  //customcolors->setFixedSize(iw, customcolors->height());
   ml->addWidget(l);
   ml->addWidget(customcolors);
-  ml->activate();
 
   palettetoolbar->insertWidget(ID_CUSTOM_COLORS, iw, w);
 
@@ -770,9 +737,9 @@ bool KIconEdit::setupStatusBar()
   statusbar->insertItem("", 4);
 
   if(pprops->statusbarstat)
-    statusbar->enable(KStatusBar::Show);
+    statusbar->show();
   else
-    statusbar->enable(KStatusBar::Hide);
+    statusbar->hide();
   return true;
 }
 
@@ -786,7 +753,7 @@ bool KIconEdit::setupWhatsThis()
   QString str = i18n("Icon draw grid\n\nThe icon grid is the area where you draw the icons.\n"
                  "You can zoom in and out using the magnifying glasses on the toolbar.\n"
                  "(Tip: Hold the magnify button down for a few seconds to zoom to a predefined scale");
-  what->add(grid, str.data());
+  what->add(grid, str);
 
   str = i18n("Rulers\n\nThis is a visual represantation of the current cursor position");
   what->add(gridview->hruler(), str.data());
@@ -966,5 +933,3 @@ void KIconEdit::toggleTool(int id)
     }
   }
 }
-
-
