@@ -22,9 +22,17 @@
 #include <qstrlist.h>
 #include <qprintdialog.h>
 #include <qpaintdevicemetrics.h>
-#include "debug.h"
+
+#include <klocale.h>
+#include <ktoolbarbutton.h>
+#include <kmessagebox.h>
+
 #include "kiconedit.h"
+
+#ifndef PICS_INCLUDED
+#define PICS_INCLUDED
 #include "pics/logo.xpm"
+#endif
 
 void KIconEdit::addColors(uint n, uint *c)
 {
@@ -58,16 +66,16 @@ void KIconEdit::slotNew()
   bool cancel = false;
   if (grid->isModified()) 
   {
-    int r = KMsgBox::yesNoCancel(this, i18n("Warning"), 
+    int r = KMessageBox::warningYesNoCancel(this, 
       i18n("The current file has been modified.\nDo you want to save it?"));
     switch(r)
     {
-      case 1:
+      case 0:
         icon->save(&grid->image());
         break;
-      case 2:
+      case 1:
         break;
-      case 3:
+      case 2:
         cancel = true;
         break;
       default:
@@ -76,18 +84,6 @@ void KIconEdit::slotNew()
   }
   if(!cancel)
   {
-#ifndef KWIZARD_VERSION
-    KResize n(this, 0, true, QSize(32, 32));
-    if(n.exec())
-    {
-      grid->editClear();
-      const QSize s = n.getSize();
-      debug("Size: %d x %d", s.width(), s.height());
-      grid->setSize(s);
-      grid->setModified(false);
-      icon->cleanup();
-    }
-#else
     KNewIcon newicon(this);
     if(newicon.exec())
     {
@@ -108,33 +104,32 @@ void KIconEdit::slotNew()
         icon->cleanup();
       }
     }
-#endif
   }
 }
 
 void KIconEdit::slotOpen()
 {
   bool cancel = false;
-  if (grid->isModified()) 
+  
+  if( grid->isModified() ) 
   {
-    int r = KMsgBox::yesNoCancel(this, i18n("Warning"), 
-	i18n("The current file has been modified.\nDo you want to save it?"));
-    switch(r)
+    int r = KMessageBox::warningYesNoCancel(this, i18n("The current file has been modified.\nDo you want to save it?"));
+    switch( r )
     {
+      case 0:
+        icon->save( &grid->image() );
+        break;
       case 1:
-        icon->save(&grid->image());
         break;
       case 2:
-        break;
-      case 3:
         cancel = true;
         break;
       default:
         break;
     }
   }
-  if(!cancel)
-    icon->promptForFile(&grid->image());
+  if( !cancel )
+    icon->promptForFile( &grid->image() );
 }
 
 void KIconEdit::slotClose()
@@ -400,7 +395,7 @@ void KIconEdit::slotTools( int id )
       break;
     default:
         if(id >= 500 && id <= 600)
-          KMsgBox::message(this, i18n("Warning"), i18n("Sorry - not implemented."));
+          KMessageBox::sorry(this, i18n("Sorry - not implemented."));
       break;
   }
 }
@@ -499,7 +494,7 @@ void KIconEdit::slotUpdateStatusName(const char *name)
     cap += " - ";
     addRecent(name);
   }
-  cap += kapp->getCaption();
+  cap += kapp->caption();
   setCaption(cap.data());
 }
 
@@ -525,6 +520,7 @@ void KIconEdit::slotOpenBlank(const QSize s)
   grid->loadBlank( s.width(), s.height());
 }
 
+#if 0
 void KIconEdit::slotDropEvent( KDNDDropZone * _dropZone )
 {
   debug("KIconEdit::slotDropEvent");
@@ -548,6 +544,9 @@ void KIconEdit::slotDropEvent( KDNDDropZone * _dropZone )
     }
   }    
 }
+#else
+#warning WABA: This drag & drop stuff is currently broken
+#endif
 
 void KIconEdit::slotQDropEvent( QDropEvent *e )
 {
@@ -627,7 +626,3 @@ void KIconEdit::slotQDragEnterEvent( QDragEnterEvent *e )
   else
     e->ignore();
 }
-
-
-
-
