@@ -16,14 +16,21 @@
     along with this library; see the file COPYING.LIB.  If not, write to
     the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
     Boston, MA 02111-1307, USA.
-*/  
+*/
+
+#include <stdlib.h>
 
 #include <kpixmap.h>
 #include <kruler.h>
-#include "debug.h"
+#include <klocale.h>
+#include <kmessagebox.h>
+
 #include "kicongrid.h"
 #include "main.h"
+#ifndef PICS_INCLUDED
 #include "pics/logo.xpm"
+#define PICS_INCLUDED
+#endif
 
 KGridView::KGridView(QImage *image, QWidget *parent, const char *name) : QFrame(parent, name)
 {
@@ -33,7 +40,7 @@ KGridView::KGridView(QImage *image, QWidget *parent, const char *name) : QFrame(
   _grid = 0L;
 
   acceptdrop = false;
-  
+
   pprops = props(this);
 
   viewport = new QScrollView(this);
@@ -62,12 +69,12 @@ KGridView::KGridView(QImage *image, QWidget *parent, const char *name) : QFrame(
   _corner = new QFrame(this);
   _corner->setFrameStyle(QFrame::WinPanel | QFrame::Raised);
 
-  _hruler = new KRuler(KRuler::horizontal, this);
+  _hruler = new KRuler(Qt::Horizontal, this);
   _hruler->setEndLabel(i18n("width"));
   _hruler->setOffset( 0 );
   _hruler->setRange(0, 1000);
 
-  _vruler = new KRuler(KRuler::vertical, this);
+  _vruler = new KRuler(Qt::Vertical, this);
   _vruler->setEndLabel(i18n("height"));
   _vruler->setOffset( 0 );
   _vruler->setRange(0, 1000);
@@ -102,17 +109,17 @@ void KGridView::setSizes()
     _hruler->setBigMarkDistance(10);
     _vruler->setBigMarkDistance(10);
 
-    _hruler->showTinyMarks(true);
-    _hruler->showLittleMarks(false);
-    _hruler->showMediumMarks(true);
-    _hruler->showBigMarks(true);
-    _hruler->showEndMarks(true);
+    _hruler->setShowTinyMarks(true);
+    _hruler->setShowLittleMarks(false);
+    _hruler->setShowMediumMarks(true);
+    _hruler->setShowBigMarks(true);
+    _hruler->setShowEndMarks(true);
 
-    _vruler->showTinyMarks(true);
-    _vruler->showLittleMarks(false);
-    _vruler->showMediumMarks(true);
-    _vruler->showBigMarks(true);
-    _vruler->showEndMarks(true);
+    _vruler->setShowTinyMarks(true);
+    _vruler->setShowLittleMarks(false);
+    _vruler->setShowMediumMarks(true);
+    _vruler->setShowBigMarks(true);
+    _vruler->setShowEndMarks(true);
 
     _hruler->setValuePerLittleMark(_grid->scaling());
     _vruler->setValuePerLittleMark(_grid->scaling());
@@ -210,7 +217,7 @@ void KGridView::paintDropSite()
   p.end();
 }
 
-void KGridView::paintEvent(QPaintEvent *e)
+void KGridView::paintEvent(QPaintEvent *)
 {
   //if(acceptdrop)
     //paintDropSite();
@@ -256,7 +263,6 @@ const QImage *fixTransparence(QImage *image)
 KIconEditGrid::KIconEditGrid(QImage *image, QWidget *parent, const char *name)
  : KColorGrid(parent, name, 1)
 {
-  initMetaObject();
   img = image;
   selected = 0;
 
@@ -682,7 +688,7 @@ void KIconEditGrid::load( QImage *image)
   else
   {
     QString msg = i18n("There was an error loading a blank image.\n");
-    KMsgBox::message (this, i18n("Error"), msg.data());
+    KMessageBox::error(this, msg);
     return;
   }
 
@@ -768,55 +774,23 @@ bool KIconEditGrid::zoom(Direction d)
 void KIconEditGrid::checkClipboard()
 {
   bool ok = false;
-  const QImage *tmp = clipboardImage(ok);
-  if(tmp)
-    delete tmp;
+  QImage tmp = clipboardImage(ok);
   if(ok)
     emit clipboarddata(true);
   else
     emit clipboarddata(false);
 }
 
-// PIXMAP format still isn't supported. It shouldn't be that hard - maybe I should have a look?
-/*  
-const QImage *KIconEditGrid::clipboardImage(bool &ok)
+QImage KIconEditGrid::clipboardImage(bool &ok)
 {
-  QPixmap pix = *kapp->clipboard()->pixmap();
-  QImage *image = new QImage;
-  if(pix.isNull())
-    debug("Invalid pixmap in clipboard!");
-  else
-  {
-    debug("Valid pixmap in clipboard!");
-    *image = pix;
+  QImage image = kapp->clipboard()->image();
+  ok = !image.isNull();
+  if ( ok ) {
+      image = image.convertDepth(32);
+      image.setAlphaBuffer(true);
   }
   return image;
 }
-*/
-
-// the caller *must* delete the image afterwards
-const QImage *KIconEditGrid::clipboardImage(bool &ok)
-{
-  ok = false;
-  QString str = kapp->clipboard()->text();
-  QBuffer buf(str);
-  buf.open(IO_ReadOnly);
-  QImageIO iio;
-  iio.setIODevice(&buf);
-  iio.setFormat("XPM");
-  
-  QImage *image = 0L;
-  if(iio.read() && !iio.image().isNull())
-  {
-    image = new QImage(iio.image().convertDepth(32));
-    image->setAlphaBuffer(true);
-    ok = true;
-  }
-
-  buf.close();
-
-  return image;
-}
 
 
 void KIconEditGrid::editSelectAll()
@@ -841,16 +815,14 @@ void KIconEditGrid::editClear()
   emit newmessage(i18n("Cleared"));
 }
 
-// the returned image *must* be deleted by the caller.
-
-QImage *KIconEditGrid::getSelection(bool cut)
+QImage KIconEditGrid::getSelection(bool cut)
 {
   const QRect rect = pntarray.boundingRect();
   int nx = 0, ny = 0, nw = 0, nh = 0;
   rect.rect(&nx, &ny, &nw, &nh);
 
-  QImage *tmp = new QImage(nw, nh, 32);
-  tmp->fill(TRANSPARENT);
+  QImage tmp(nw, nh, 32);
+  tmp.fill(TRANSPARENT);
 
   int s = pntarray.size(); //((rect.size().width()) * (rect.size().height()));
   for(int i = 0; i < s; i++)
@@ -859,7 +831,7 @@ QImage *KIconEditGrid::getSelection(bool cut)
     int y = pntarray[i].y();
     if(img->valid(x, y) && rect.contains(QPoint(x, y)))
     {
-      *((uint*)tmp->scanLine(y-ny) + (x-nx)) = *((uint*)img->scanLine(y) + x);
+      *((uint*)tmp.scanLine(y-ny) + (x-nx)) = *((uint*)img->scanLine(y) + x);
       if(cut)
       {
         *((uint*)img->scanLine(y) + x) = TRANSPARENT;
@@ -888,111 +860,35 @@ QImage *KIconEditGrid::getSelection(bool cut)
   return tmp;
 }
 
-// the returned image *must* be deleted by the caller.
-/*
-QImage *KIconEditGrid::getSelection(bool cut)
-{
-  const QRect rect = pntarray.boundingRect();
-
-  int nx = 0, ny = 0, nw = 0, nh = 0;
-  rect.rect(&nx, &ny, &nw, &nh);
-  debug("KIconEditGrid: Selection Rect: %d %d %d %d", nx, ny, nw, nh);
-
-  QImage *tmp = new QImage(nw, nh, 32);
-
-  QApplication::setOverrideCursor(waitCursor);
-  for(int y = 0; y < nh; y++)
-  {
-    uint *l = ((uint*)img->scanLine(y+ny)+nx);
-    uint *cl = (uint*)tmp->scanLine(y);
-    for(int x = 0; x < nw; x++, l++, cl++)
-    {
-      *cl = *l;
-      if(cut)
-      {
-        *l = TRANSPARENT;
-        setColor( ((y+ny)*numCols()) + (x+nx), TRANSPARENT, false );
-      }
-    }
-    kapp->processEvents();
-  }
-
-  QApplication::restoreOverrideCursor();
-
-  QPointArray a(pntarray.copy());
-  pntarray.resize(0);
-  drawPointArray(a, Mark);
-  emit selecteddata(false);
-  if(cut)
-  {
-    updateColors();
-    repaint(rect.x()*cellSize(), rect.y()*cellSize(),
-            rect.width()*cellSize(), rect.height()*cellSize(), false);
-    p = *img;
-    emit changed(p);
-    emit colorschanged(numColors(), data());
-    emit newmessage(i18n("Selected area cutted"));
-  }
-  else
-    emit newmessage(i18n("Selected area copied"));
-  return tmp;
-}
-*/
-
 void KIconEditGrid::editCopy(bool cut)
 {
-  QImage *sel = getSelection(cut);
-
-  sel->setAlphaBuffer(true);
-  QString str = "";
-  QBuffer buf(str);
-  buf.open(IO_WriteOnly);
-  QImageIO iio;
-  iio.setImage(*sel);
-  iio.setIODevice(&buf);
-  iio.setFormat("XPM");
-  iio.setDescription("Created by KDE Draw");
-  
-  if(iio.write())
-  {
-    QClipboard *cb = kapp->clipboard();
-    cb->setText(str.data());
-    //debug(str.data());
-  }
-  else
-  {
-    QString msg = i18n("There was an copying:\nto the clipboard!");
-    KMsgBox::message(this, i18n("Warning"), msg.data(), KMsgBox::EXCLAMATION);
-  }
-  buf.close();
-  delete sel;
+  kapp->clipboard()->setImage(getSelection(cut));
   isselecting = false;
 }
 
 void KIconEditGrid::editPaste(bool paste)
 {
   bool ok = false;
-  const QImage *tmp = clipboardImage(ok);
-  fixTransparence((QImage*)tmp);
+  QImage tmp = clipboardImage(ok);
+  fixTransparence(&tmp);
 
   Properties *pprops = props(this);
 
   if(ok)
   {
-    if( (tmp->size().width() > img->size().width()) || (tmp->size().height() > img->size().height()) )
+    if( (tmp.size().width() > img->size().width()) || (tmp.size().height() > img->size().height()) )
     {
-      if(KMsgBox::yesNo(this, i18n("Warning"),
-          i18n("The clipboard image is larger than the current image!\nPaste as new image?")) == 1)
+      if(KMessageBox::warningYesNo(this,
+          i18n("The clipboard image is larger than the current image!\nPaste as new image?")) == 0)
       {
         editPasteAsNew();
       }
-      delete tmp;
       return;
     }
     else if(!paste)
     {
       ispasting = true;
-      cbsize = tmp->size();
+      cbsize = tmp.size();
       //debug("insrect size: %d x %d", insrect.width(), insrect.height());
       return;
       emit newmessage(i18n("Pasting"));
@@ -1006,7 +902,7 @@ void KIconEditGrid::editPaste(bool paste)
       for(int y = insrect.y(), ny = 0; y < numRows(), ny < insrect.height(); y++, ny++)
       {
         uint *l = ((uint*)img->scanLine(y)+insrect.x());
-        uint *cl = (uint*)tmp->scanLine(ny);
+        uint *cl = (uint*)tmp.scanLine(ny);
         for(int x = insrect.x(), nx = 0; x < numCols(), nx < insrect.width(); x++, nx++, l++, cl++)
         {
           if(*cl != TRANSPARENT || pprops->pastetransparent)
@@ -1033,19 +929,18 @@ void KIconEditGrid::editPaste(bool paste)
   else
   {
     QString msg = i18n("Invalid pixmap data in clipboard!\n");
-    KMsgBox::message(this, i18n("Warning"), msg.data());
+    KMessageBox::sorry(this, msg);
   }
-  delete tmp;
 }
 
 void KIconEditGrid::editPasteAsNew()
 {
   bool ok = false;
-  const QImage *tmp = clipboardImage(ok);
+  QImage tmp = clipboardImage(ok);
 
   if(ok)
   {
-    *img = *tmp;
+    *img = tmp;
     load(img);
     modified = true;
     //repaint(viewRect(), false);
@@ -1059,9 +954,8 @@ void KIconEditGrid::editPasteAsNew()
   else
   {
     QString msg = i18n("Invalid pixmap data in clipboard!\n");
-    KMsgBox::message(this, i18n("Warning"), msg.data());
+    KMessageBox::error(this, msg);
   }
-  delete tmp;
 }
 
 //#if QT_VERSION >= 140
@@ -1069,7 +963,7 @@ void KIconEditGrid::editResize()
 {
   debug("KIconGrid::editResize");
 #if QT_VERSION >= 140
-  KResize *rs = new KResize(this, 0, true, QSize(numCols(), numRows()));
+  KResizeDialog *rs = new KResizeDialog(this, 0, QSize(numCols(), numRows()));
   if(rs->exec())
   {
     const QSize s = rs->getSize();
@@ -1093,17 +987,16 @@ void KIconEditGrid::setSize(const QSize s)
 
 void KIconEditGrid::createCursors()
 {
-  KIconLoader *loader = kapp->getIconLoader();
-  QBitmap bmp, mask(22, 22);
+    QBitmap bmp, mask(22, 22);
   QPixmap pix;
 
   cursor_normal = QCursor(arrowCursor);
 
-  pix = loader->loadIcon("paintbrush.xpm");
+  pix = BarIcon("paintbrush");
   if(pix.isNull())
   {
     cursor_paint = cursor_normal;
-    debug("KIconEditGrid: Error loading pixmap: paintbrush.xpm"); 
+    debug("KIconEditGrid: Error loading pixmap: paintbrush.xpm");
   }
   else
   {
@@ -1112,11 +1005,11 @@ void KIconEditGrid::createCursors()
     cursor_paint = QCursor(bmp, mask, 6, 18);
   }
 
-  pix = loader->loadIcon("flood.xpm");
+  pix = BarIcon("flood");
   if(pix.isNull())
   {
     cursor_flood = cursor_normal;
-    debug("KIconEditGrid: Error loading pixmap: flood.xpm"); 
+    debug("KIconEditGrid: Error loading pixmap: flood.xpm");
   }
   else
   {
@@ -1125,11 +1018,11 @@ void KIconEditGrid::createCursors()
     cursor_flood = QCursor(bmp, mask, 5, 16);
   }
 
-  pix = loader->loadIcon("aim.xpm");
+  pix = BarIcon("aim");
   if(pix.isNull())
   {
     cursor_aim = cursor_normal;
-    debug("KIconEditGrid: Error loading pixmap: aim.xpm"); 
+    debug("KIconEditGrid: Error loading pixmap: aim.xpm");
   }
   else
   {
@@ -1138,11 +1031,11 @@ void KIconEditGrid::createCursors()
     cursor_aim = QCursor(bmp, mask);
   }
 
-  pix = loader->loadIcon("spraycan.xpm");
+  pix = BarIcon("spraycan");
   if(pix.isNull())
   {
     cursor_spray = cursor_normal;
-    debug("KIconEditGrid: Error loading pixmap: aim.xpm"); 
+    debug("KIconEditGrid: Error loading pixmap: aim.xpm");
   }
   else
   {
@@ -1151,11 +1044,11 @@ void KIconEditGrid::createCursors()
     cursor_spray = QCursor(bmp, mask);
   }
 
-  pix = loader->loadIcon("eraser.xpm");
+  pix = BarIcon("eraser");
   if(pix.isNull())
   {
     cursor_erase = cursor_normal;
-    debug("KIconEditGrid: Error loading pixmap: aim.xpm"); 
+    debug("KIconEditGrid: Error loading pixmap: aim.xpm");
   }
   else
   {
@@ -1234,7 +1127,7 @@ void KIconEditGrid::drawSpray(QPoint point)
   int x = (point.x()-5);
   int y = (point.y()-5);
   //debug("drawSpray() - %d X %d", x, y);
-  
+
   pntarray.resize(0);
   int points = 0;
   for(int i = 1; i < 4; i++, points++)
@@ -1578,7 +1471,7 @@ static bool kdither_32_to_8( const QImage *src, QImage *dst )
 				l2[x+1] += err>>4;
 			    }
 			    l2[x]+=(err*5)>>4;
-			    if (x>1) 
+			    if (x>1)
 				l2[x-1]+=(err*3)>>4;
 			}
 		    } else {
@@ -1593,7 +1486,7 @@ static bool kdither_32_to_8( const QImage *src, QImage *dst )
 				l2[x-1] += err>>4;
 			    }
 			    l2[x]+=(err*5)>>4;
-			    if (x+1 < sw) 
+			    if (x+1 < sw)
 				l2[x+1]+=(err*3)>>4;
 			}
 		    }
@@ -1691,5 +1584,3 @@ void KIconEditGrid::grayScale()
   load(img);
   modified = true;
 }
-
-
