@@ -22,23 +22,23 @@
 #define __KICONEDITGRID_H__
 
 #include <qdir.h>
-#include <qdrawutl.h>
+#include <qdrawutil.h>
 #include <qbrush.h>
 #include <qpixmap.h>
 #include <qimage.h>
 #include <qbitmap.h>
 #include <qbuffer.h>
-#include <qclipbrd.h>
-#include <qfileinf.h>
+#include <qclipboard.h>
+#include <qfileinfo.h>
 #if QT_VERSION >= 140
 #include <qgroupbox.h>
 #else
-#include <qgrpbox.h>
+#include <qgroupbox.h>
 #endif 
-#include <qbttngrp.h>
+#include <qbuttongroup.h>
 #include <qcursor.h>
 #include <qlayout.h>
-#include <qpntarry.h>
+#include <qpointarray.h>
 #include <qdialog.h>
 #include <qstrlist.h>
 #include <qtimer.h>
@@ -46,8 +46,6 @@
 #include <kcolordlg.h>
 #include <kiconloader.h>
 #include <kapp.h>
-#include <kmsgbox.h>
-#include <kintegerline.h>
 #include <kpixmap.h>
 #include "utils.h"
 #include "kcolorgrid.h"
@@ -116,8 +114,8 @@ public:
   void setModified(bool m) { modified = m; }
   const QPixmap &pixmap();
   const QImage &image() { return *img; }
-  const QImage *clipboardImage(bool &ok);
-  QImage *getSelection(bool);
+  QImage clipboardImage(bool &ok);
+  QImage getSelection(bool);
   int rows() { return numRows(); };
   int cols() { return numCols(); };
   uint getColors( uint *_colors) { return colors(_colors); }
