@@ -24,7 +24,7 @@ protected:
   virtual void activating();
   virtual void deactivating();
   virtual void timerEvent(QTimerEvent *);
-  QPixmap *pixmap();
+  virtual QPixmap pixmap() const;
 
 private:
   void drawFrame();
