@@ -1,12 +1,12 @@
-// $Id: canvassize.h,v 1.4 1998/05/07 13:34:29 rich Exp $
+// $Id: canvassize.h,v 1.5 1999/03/01 23:32:07 kulow Exp $
 
 #ifndef CANVASSIZE_H
 #define CANVASSIZE_H
 
 #include <qdialog.h>
 #include <qlabel.h>
-#include <qlined.h>
-#include <qpushbt.h>
+#include <qlineedit.h>
+#include <qpushbutton.h>
 
 class canvasSizeDialog : public QDialog
 {
