@@ -1,5 +1,5 @@
 // -*- c++ -*-
-// $Id: circle.h,v 1.5 1998/10/18 19:59:42 habenich Exp $
+// $Id: circle.h,v 1.6 1999/06/19 23:17:04 kulow Exp $
 
 #ifndef CIRCLE_H
 #define CIRCLE_H
@@ -16,7 +16,7 @@ public:
   void mouseMoveEvent(QMouseEvent *e);
   void mouseReleaseEvent(QMouseEvent *e);
   void activating();
-  QPixmap *pixmap();
+  QPixmap pixmap() const;
 signals:
   void modified();
 
