@@ -3,7 +3,7 @@
 // Line class
 // This class is a subclass of Tool and provides a rubber line drawing tool.
 
-// $Id: line.h,v 1.5 1998/10/18 19:59:54 habenich Exp $
+// $Id: line.h,v 1.6 1999/06/19 23:17:06 kulow Exp $
 
 #ifndef LINE_H
 #define LINE_H
@@ -20,7 +20,7 @@ public:
   void mouseMoveEvent(QMouseEvent *e);
   void mouseReleaseEvent(QMouseEvent *e);
   void activating();
-  QPixmap *pixmap();
+  virtual QPixmap pixmap() const;
 signals:
   void modified();
 private:
