@@ -5,13 +5,13 @@
 #include <qlayout.h>
 
 #include "view.h"
-#include "QwViewport.h"
+#include <qscrollview.h>
 #include "canvas.h"
 #include "sidebar.h"
 #include "colorbar.h"
 
 MainView::MainView(QWidget *parent, const char *name)
-  : QDialog(parent,name)
+  : QWidget(parent,name)
 {
   int w, h; 
   w= 300;
@@ -20,8 +20,10 @@ MainView::MainView(QWidget *parent, const char *name)
   lm = new QBoxLayout(this, QBoxLayout::TopToBottom);
 
   view= new View(this, "view container");
-  v= new QwViewport(view);
-  c= new Canvas(w, h, v->portHole());
+
+  v= new QScrollView(view);
+  c= new Canvas(w, h, v->viewport());
+  v->addChild(c);
 
   lm->addWidget(view);
 
