@@ -4,10 +4,10 @@
 #define MAINVIEW_H
 
 
-#include <qdialog.h>
+#include <qwidget.h>
 
 class View;
-class QwViewport;
+class QScrollView;
 class Canvas;
 class QBoxLayout;
 class SideBar;
@@ -17,13 +17,13 @@ class ColorBar;
  * view window for kpaint
  * just created for layout.
  */
-class MainView : public QDialog
+class MainView : public QWidget
 {
 Q_OBJECT
 public:
 MainView(QWidget *parent=0, const char *name=0);
 
-  inline QwViewport *getViewport() const;
+  inline QScrollView *getViewport() const;
   inline Canvas *getCanvas() const;
   inline SideBar * getSideBar() const;
   inline ColorBar *getDefaultColorBar() const;
@@ -32,7 +32,7 @@ private:
 
   // Child widgets
   View *view;
-  QwViewport *v;
+  QScrollView *v;
   Canvas *c;
   SideBar *side;
   ColorBar *dcb;
@@ -42,7 +42,7 @@ private:
 
 };
 
-QwViewport *
+QScrollView *
 MainView::getViewport() const
 {
   return v;
