@@ -43,7 +43,7 @@ void NavWidget::setPixmap(QPixmap *p)
 
 void NavWidget::pixmapChanged()
 {
-  KDEBUG(KDEBUG_INFO, 3000, "NavWidget::pixmapChanged()\n");
+  kdDebug(3000) << "NavWidget::pixmapChanged()\n" << endl;
   repaint(FALSE);
 }
 
