@@ -22,7 +22,7 @@ it as selector for the colours).
 */
 
 
-#include <qtablevw.h>
+#include <qtableview.h>
 #include <qpixmap.h>
 #include <qpainter.h>
 #include <qimage.h>
