@@ -1,5 +1,5 @@
 #include <kdebug.h>
-#include <qpushbt.h>
+#include <qpushbutton.h>
 #include <klocale.h>
 #include <kapp.h>
 #include "palettedialog.h"
@@ -11,7 +11,7 @@ paletteDialog::paletteDialog(QPixmap *p, QWidget *parent, const char *name)
   pal= new paletteWidget(p, this);
 
   resize(340, 280);
-  dismiss = new QPushButton( klocale->translate("Dismiss"), this );
+  dismiss = new QPushButton( i18n("Dismiss"), this );
   dismiss->setAutoResize(TRUE);
   pal->move(10, 10);
   pal->resize(320, 240);
