@@ -1,4 +1,4 @@
-// $Id: pen.cpp,v 1.12 1998/10/18 19:59:57 habenich Exp $
+// $Id: pen.cpp,v 1.21 2000/06/05 11:04:59 hoelzer Exp $
 
 #include <kdebug.h>
 #include <stdio.h>
@@ -9,7 +9,7 @@
 #include <qwmatrix.h>
 #include <klocale.h>
 #include "pen.h"
-#include "app.h"
+#include <kiconloader.h>
 
 Pen::Pen(const char *toolname) : Tool(toolname)
 {
@@ -20,7 +20,7 @@ Pen::Pen(const char *toolname) : Tool(toolname)
 
 void Pen::activating()
 {
-  KDEBUG1(KDEBUG_INFO, 3000, "Pen::activating() hook called canvas=%p\n", canvas);
+  kdDebug(3000) << "Pen::activating() hook called canvas=" << canvas << "\n" << endl;
   drawing= FALSE;
 
   canvas->setCursor(crossCursor);
@@ -33,11 +33,11 @@ void Pen::mousePressEvent(QMouseEvent *e)
   QPainter painter2;
   QWMatrix m;
 
-  KDEBUG(KDEBUG_INFO, 3000, "Pen::mousePressEvent() handler called\n");
+  kdDebug(3000) << "Pen::mousePressEvent() handler called\n" << endl;
   
   if (isActive()) {
     if (drawing) {
-      KDEBUG(KDEBUG_INFO, 3000, "Pen: Warning button press received while drawing\n");
+      kdDebug(3000) << "Pen: Warning button press received while drawing\n" << endl;
     }
     x= (e->pos()).x();
     y= (e->pos()).y();
@@ -72,7 +72,7 @@ void Pen::mousePressEvent(QMouseEvent *e)
     drawing= TRUE;
   } 
   if (!isActive()) {
-    KDEBUG(KDEBUG_WARN, 3000, "Warning event received when inactive (ignoring)\n");
+    kdWarning(3000) << "Warning event received when inactive (ignoring)\n" << endl;
   }
 }
 
@@ -122,29 +122,23 @@ void Pen::mouseMoveEvent(QMouseEvent *e)
     }
   }
   else {
-    KDEBUG(KDEBUG_WARN, 3000, "Warning event received when inactive (ignoring)\n");
+    kdWarning(3000) << "Warning event received when inactive (ignoring)\n" << endl;
   }
 }
 
 void Pen::mouseReleaseEvent(QMouseEvent *e)
 {
-  KDEBUG(KDEBUG_INFO, 3000, "Pen::mouseReleaseEvent() handler called\n");
+  kdDebug(3000) << "Pen::mouseReleaseEvent() handler called\n" << endl;
   if (isActive() && (e->button() == activeButton) && drawing)
     drawing= FALSE;
   if (!isActive()) {
-    KDEBUG(KDEBUG_WARN, 3000, "Warning event received when inactive (ignoring)\n");
+    kdWarning(3000) << "Warning event received when inactive (ignoring)\n" << endl;
   }
 }
 
-QPixmap *Pen::pixmap()
+QPixmap Pen::pixmap() const
 {
-  QString pixdir;
-
-  pixdir= myapp->kde_datadir().copy();
-  pixdir.append("/kpaint/toolbar/");
-
-  pixdir.append("pen.xpm");
-  return new QPixmap(pixdir);
+    return UserIcon("pen");
 }
 
 #include "pen.moc"
