@@ -1,5 +1,5 @@
 // -*- c++ -*-
-// $Id: pen.h,v 1.5 1998/10/18 19:59:59 habenich Exp $
+// $Id: pen.h,v 1.6 1999/06/19 23:17:07 kulow Exp $
 
 #ifndef PEN_H
 #define PEN_H
@@ -17,7 +17,7 @@ public:
   void mouseMoveEvent(QMouseEvent *e);
   void mouseReleaseEvent(QMouseEvent *e);
   void activating();
-  QPixmap *pixmap();
+    virtual QPixmap pixmap() const;
 signals:
   void modified();
 private:
