@@ -1,10 +1,10 @@
 #include <kdebug.h>
 #include <qcolor.h>
-#include <qtabdlg.h>
-#include <qpushbt.h>
+#include <qtabdialog.h>
+#include <qpushbutton.h>
 #include <qlabel.h>
-#include <qlined.h>
-#include <qcombo.h>
+#include <qlineedit.h>
+#include <qcombobox.h>
 #include <qlayout.h>
 #include <stdio.h>
 #include <kcolordlg.h>
@@ -12,6 +12,8 @@
 #include <kapp.h>
 #include "properties.h"
 
+#define SETMINSIZE(w) w->setMinimumSize(w->sizeHint())
+
 propertiesDialog::propertiesDialog(int pages,
 				   QWidget *parent, const char *name)
   : QTabDialog(parent, name)
@@ -25,7 +27,6 @@ propertiesDialog::propertiesDialog(int pages,
   setCancelButton( i18n( "Cancel" ) );
   setApplyButton( i18n( "Apply" ));
   setPages(pages);
-
 }
 
 QBrush &propertiesDialog::getBrush()
@@ -103,7 +104,7 @@ fillPropertiesWidget::fillPropertiesWidget(QWidget *parent)
   browseButton= new QPushButton(i18n("Browse..."), this);
   browseButton->move(150, 150);
 
-  setFillColourButton= new QPushButton(i18n("Set Fill Colour..."), this);
+  setFillColourButton= new QPushButton(i18n("Set Fill Color..."), this);
   setFillColourButton->move(40, 200);
   setFillColourButton->setEnabled(false);
   pattern= new QPixmap();
@@ -123,6 +124,7 @@ fillPropertiesWidget::fillPropertiesWidget(QWidget *parent)
   vertical->addLayout(grid);
 
   patternLabel= new QLabel(i18n("Fill Pattern:"), this);
+  SETMINSIZE(patternLabel);
   grid->addWidget(patternLabel, 0, 0);
 
   // Need to use an item that can display a sample of each one
@@ -142,14 +144,17 @@ fillPropertiesWidget::fillPropertiesWidget(QWidget *parent)
   patternBox->insertItem("37%");
   patternBox->insertItem("12%");
   patternBox->insertItem("6%");
+  SETMINSIZE(patternBox);
   grid->addWidget(patternBox, 0, 1);
 
   //  patternBox->insertItem(i18n("Custom"));
 
   customPatternLabel= new QLabel(i18n("Pattern Filename:"), this);
+  SETMINSIZE(customPatternLabel);
   grid->addWidget(customPatternLabel, 1, 0);
 
   customPatternField= new QLineEdit(this);
+  SETMINSIZE(customPatternField);
   grid->addWidget(customPatternField, 1, 1);
 
   //  browseButton= new QPushButton(i18n("Browse..."), this);
@@ -328,7 +333,7 @@ linePropertiesWidget::linePropertiesWidget(QWidget *parent)
   joinStyleBox->move(150, 200);
 
 
-  setLineColourButton= new QPushButton(i18n("Set Line Colour..."), this);
+  setLineColourButton= new QPushButton(i18n("Set Line Color..."), this);
   setLineColourButton->move(40, 240);
   connect(setLineColourButton, SIGNAL(clicked()), this, SLOT(setLineColour()) );
   setLineColourButton->setEnabled(false);
