@@ -15,7 +15,7 @@ public:
   void mouseMoveEvent(QMouseEvent *e);
   void mouseReleaseEvent(QMouseEvent *e);
   void activating();
-  QPixmap *pixmap();
+  QPixmap pixmap() const;
 signals:
   void modified();
 private:
