@@ -1,6 +1,6 @@
 // -*- c++ -*-
 
-// $Id: spraycan.h,v 1.5 1998/10/18 20:00:06 habenich Exp $
+// $Id: spraycan.h,v 1.6 1999/06/19 23:17:08 kulow Exp $
 
 #ifndef SPRAYCAN_H
 #define SPRAYCAN_H
@@ -20,7 +20,7 @@ public:
   void mouseMoveEvent(QMouseEvent *e);
   void mouseReleaseEvent(QMouseEvent *e);
   void activating();
-  QPixmap *pixmap();
+  QPixmap pixmap() const;
 signals:
   void modified();
 private:
