@@ -20,7 +20,7 @@ Text(const char *toolname);
   //  void mouseMoveEvent(QMouseEvent *e);
   void mouseReleaseEvent(QMouseEvent *);
   void keyPressEvent(QKeyEvent *);
-  QPixmap *pixmap();
+  QPixmap pixmap() const;
 
 signals:
   //  void modified();
