@@ -1,4 +1,4 @@
-// $Id: tool.cpp,v 1.8 1998/10/18 20:00:07 habenich Exp $
+// $Id: tool.cpp,v 1.12 2000/06/05 11:04:59 hoelzer Exp $
 
 #include <kdebug.h>
 #include <stdio.h>
@@ -52,31 +52,26 @@ bool Tool::isActive()
 
 void Tool::setLeftPen(QPen &p)
 {
-  KDEBUG(KDEBUG_INFO, 3000, "Tool::setLeftPen()\n");
+  kdDebug(3000) << "Tool::setLeftPen()\n" << endl;
   leftpen= p;
 }
 
 void Tool::setLeftBrush(QBrush &b)
 {
-  KDEBUG(KDEBUG_INFO, 3000, "Tool::setLeftBrush()\n");
+  kdDebug(3000) << "Tool::setLeftBrush()\n" << endl;
   leftbrush= b;
 }
 
 void Tool::setRightPen(QPen &p)
 {
-  KDEBUG(KDEBUG_INFO, 3000, "Tool::setRightPen()\n");
+  kdDebug(3000) << "Tool::setRightPen()\n" << endl;
   rightpen= p;
 }
 
 void Tool::setRightBrush(QBrush &b)
 {
-  KDEBUG(KDEBUG_INFO, 3000, "Tool::setRightBrush()\n");
+  kdDebug(3000) << "Tool::setRightBrush()\n" << endl;
   rightbrush= b;
 }
 
-QPixmap *Tool::pixmap()
-{
-  return 0;
-}
-
 #include "tool.moc"
