@@ -1,5 +1,5 @@
 #include "view.h"
-#include "QwViewport.h"
+#include <qscrollview.h>
 #include "sidebar.h"
 
 View::View(QWidget *parent, const char *name)
