@@ -5,7 +5,7 @@
 
 #include <qwidget.h>
 
-class QwViewport;
+class QScrollView;
 class SideBar;
 
 /**
@@ -20,7 +20,7 @@ public:
   void resizeEvent(QResizeEvent *);
   void updateRects();
 
-  QwViewport *c;
+  QScrollView *c;
   SideBar *s;
 };
 
