@@ -9,15 +9,17 @@
 #include <qwidget.h>
 #include <qpixmap.h>
 #include <qimage.h>
-#include <qpushbt.h>
+#include <qpushbutton.h>
 #include <qlabel.h>
-#include <qlined.h>
+#include <qlineedit.h>
 #include <qtimer.h>
 #include <qlayout.h>
-#include <qchkbox.h>
-#include <kbutton.h>
+#include <qcheckbox.h>
 #include "preview.h"
 
+class QToolButton;
+
+
 class KSnapShot : public QWidget
 {
   Q_OBJECT
@@ -27,8 +29,9 @@ public:
   ~KSnapShot();
 
   void startGrab();
-  void performGrab();
+  void performGrab( bool initial=false );
   void resizeEvent(QResizeEvent *);
+  void autoincFilename();
 
 signals:
   void doneGrab();
@@ -38,10 +41,10 @@ public slots:
   void autoRaiseToggledSlot();
   void hideSelfToggledSlot();
   void grabWindowToggledSlot();
-  void filenameChangedSlot(const char *);
-  void formatChangedSlot(const char *);
+  void filenameChangedSlot(const QString&);
   void browsePressedSlot();
-  void delayChangedSlot(const char *text);
+  void delayChangedSlot(const QString&);
+  void repeatChangedSlot(const QString&);
   void helpSlot();
   void closeSlot();
   void showPreviewSlot();
@@ -53,16 +56,13 @@ protected slots:
 
 protected:
   // The widgets
-  QLabel *titleLabel;
   QLabel *logoLabel;
-  QHBoxLayout *titleLayout;
   QLabel *hintLabel;
   QVBoxLayout *infoLayout;
-  KButton *previewButton;
+  QToolButton *previewButton;
   QLabel *filenameLabel;
   QLineEdit *filenameEdit;
   QPushButton *browseButton;
-  QComboBox *formatBox;
   QHBoxLayout *filenameLayout;
   QLabel *delayLabel;
   QLineEdit *delayEdit;
@@ -82,6 +82,12 @@ protected:
   QPushButton *closeButton;
   Preview *previewWindow;
 
+  QLabel *repeatLabel;
+  QLineEdit *repeatEdit;
+  QLabel *timesLabel;
+  int repeat_;
+  bool hidden;
+
   void buildGui();
   void updatePreview();
 
@@ -95,11 +101,11 @@ private:
   bool autoRaise_;
   bool grabWindow_;
   bool grabDesktop_;
+  bool autoincFilename_;
   QPixmap snapshot_;
   int delay_;
   QTimer *timer_;
   QString filename_;
-  QString format_;
   Window child;
 };
 
