@@ -1,7 +1,7 @@
 #include "preview.h"
 
 Preview::Preview()
-  : QPushButton()
+  : QPushButton(QString::null, 0)
 {
 
 }
@@ -11,7 +11,7 @@ Preview::~Preview()
 
 }
 
-void Preview::closeEvent(QCloseEvent *e)
+void Preview::closeEvent(QCloseEvent *)
 {
   emit clicked();
 }
