@@ -1,43 +1,44 @@
 /*
 * viewer.cpp -- Implementation of class KImageViewer.
 * Author:	Sirtaj Singh Kang
-* Version:	$Id: viewer.cpp,v 1.20 1999/01/19 02:12:27 ssk Exp $
+* Version:	$Id: viewer.cpp,v 1.47 2000/05/24 09:34:33 kulow Exp $
 * Generated:	Wed Oct 15 11:37:16 EST 1997
 */
 
-#include<assert.h>
-#include<stdio.h>
+#include <assert.h>
+#include <stdio.h>
+#include <unistd.h>
 
-#include<qpopmenu.h>
-#include<qmsgbox.h>
-#include<qprintdialog.h>
-#include<qprinter.h>
-#include<qstrlist.h>
-#include<qaccel.h>
-#include<qtimer.h>
-#include<qevent.h>
+#include <qpopupmenu.h>
+#include <qprintdialog.h>
+#include <qprinter.h>
+#include <qstrlist.h>
+#include <qaccel.h>
+#include <qtimer.h>
+#include <qevent.h>
+#include <qdragobject.h>
 
-#include<ktopwidget.h>
-#include<kmenubar.h>
-#include<kapp.h>
-#include<drag.h>
-#include<kfiledialog.h>
-#include<kstring.h>
-#include<kfm.h>
-#include<kaccel.h>
-#include<kaccelmenuwatch.h>
+#include <ktmainwindow.h>
+#include <kmenubar.h>
+#include <kapp.h>
+#include <kfiledialog.h>
+#include <kaccel.h>
+#include <kaccelmenuwatch.h>
+#include <kmessagebox.h>
+#include <klocale.h>
+#include <kconfig.h>
+#include <kimageio.h>
+#include <kio/netaccess.h>
 
-#include"viewer.h"
-#include"canvas.h"
-#include"version.h"
-#include"numdlg.h"
-#include"prefdlg.h"
-
-#include"filter.h"
-#include"filtmenu.h"
-#include"filtlist.h"
-
-#include"ilistdlg.h"
+#include "viewer.h"
+#include "canvas.h"
+#include "version.h"
+#include "numdlg.h"
+#include "prefdlg.h"
+#include "filter.h"
+#include "filtmenu.h"
+#include "filtlist.h"
+#include "ilistdlg.h"
 
 enum {
 	StatProgress,
@@ -47,7 +48,7 @@ enum {
 const int MessageDelay = 3000;
 
 KImageViewer::KImageViewer()
-	: KTopLevelWidget(),
+	: KTMainWindow(),
 	_imageLoaded( false ),
 
 
@@ -66,9 +67,7 @@ KImageViewer::KImageViewer()
 	_barFilterID( 0 ),
 	_popFilterID( 0 ),
 
-	_kfm( 0 ),
-	_transSrc( 0 ),
-	_transDest( 0 ),
+        _iojob( 0 ),
 	_menuFact( 0 ),
 	_pctBuffer( new QString ),
 	_lastPct( - 1 ),
@@ -78,211 +77,198 @@ KImageViewer::KImageViewer()
 
 	_loadMode   ( ResizeWindow )
 {
-
-	// Image canvas
-	_canvas = new KImageCanvas( this );
+   // Image canvas
+   _canvas = new KImageCanvas( this );
 	
-	connect(_canvas, SIGNAL( contextPress(const QPoint&) ), 
-		this, SLOT ( contextPress(const QPoint&) ));
+   connect(_canvas, SIGNAL( contextPress(const QPoint&) ), 
+           this, SLOT ( contextPress(const QPoint&) ));
 
-	assert( _canvas );
-	setView( _canvas, FALSE );
+   assert( _canvas );
+   setView( _canvas, FALSE );
 	
-	// Caption
-	QString cap;
-	cap = kapp->appName().data();
-	cap += " - ";
-	cap += i18n( "no image loaded" );
-	setCaption( cap );
+   // Caption
+   setCaption( i18n( "no image loaded" ) );
 
-	// status bar
-	_statusbar = new KStatusBar( this );
-	setStatusBar( _statusbar );
+   // status bar
+   _statusbar = new KStatusBar( this );
+   setStatusBar( _statusbar );
 
-	_statusbar->insertItem( "                 ", StatProgress );
-	_statusbar->insertItem( i18n( "Ready" ), StatStatus );
+   _statusbar->insertItem( "                 ", StatProgress );
+   _statusbar->insertItem( i18n( "Ready" ), StatStatus );
 
-	// list dialog
-	connect( _imageList, SIGNAL(selected(const char *)),
-		this, SLOT(loadURL(const char *)) );
+   // list dialog
+   connect( _imageList, SIGNAL(selected(const KURL &)),
+            this, SLOT(loadURL(const KURL &)) );
 
-	// accelerators
-	makeAccel();
+   // accelerators
+   makeAccel();
 
-	// Drop events forwarded to image list object
-
-	KDNDDropZone *dropObserver = new KDNDDropZone( this, DndURL );
-
-	QObject::connect( dropObserver, SIGNAL(dropAction(KDNDDropZone *)),
-			_imageList, SLOT(dropEvent(KDNDDropZone *)) );
-
-	restoreOptions( kapp->getConfig() );
+   setAcceptDrops(true);
+   restoreOptions( kapp->config() );
 }
 
 KImageViewer::~KImageViewer()
 {
-	delete _canvas; _canvas = 0;
+   delete _canvas; _canvas = 0;
 
-	delete _file;
-	delete _edit;
-	delete _zoom;
-	delete _transform;
-	delete _desktop;
-	delete _aggreg;
-	delete _help;
+   delete _file;
+   delete _edit;
+   delete _zoom;
+   delete _transform;
+   delete _desktop;
+   delete _aggreg;
+   delete _help;
 
-	delete _contextMenu;
+   delete _contextMenu;
 
-	delete _pctBuffer;
-	delete _imageList;
-
-
-	delete _kfm; _kfm = 0;
-
-	delete _transSrc;
-	_transSrc = 0;
-
-	delete _transDest;
-	_transDest = 0;
+   delete _pctBuffer;
+   delete _imageList;
 }
 
 void KImageViewer::load()
 {
-	KFileDialog dlg( "", 0, 0, 0, true, true );
-	QString URL = dlg.getOpenFileURL();
+   KURL URL = KFileDialog::getOpenURL(QString::null, 
+		KImageIO::pattern(KImageIO::Reading), this);
 
-	if( URL.length() <= 0 ) {
-		return;
-	}
+   if( URL.isEmpty())
+      return;
 
-	_imageList->addURL( URL );
+   _imageList->addURL( URL );
+}
+
+void KImageViewer::dragEnterEvent(QDragEnterEvent* e)
+{
+   if (QUriDrag::canDecode(e))
+   {
+      e->accept();
+   }
+}
+
+void KImageViewer::dropEvent(QDropEvent *e) 
+{
+   _imageList->dropEvent(e);
 }
 
 void KImageViewer::saveAs()
 {
-	KFileDialog dlg( "", 0, 0, 0, true, false );
-	QString urls = dlg.getSaveFileURL();
+   KURL url = KFileDialog::getSaveURL(QString::null, 
+		KImageIO::pattern(KImageIO::Reading));
 
+   if ( url.isEmpty())
+      return;
 
-	if ( urls.length() <= 0 ) {
-		return;
-	}
+   bool stat = false;
 
-	KURL url( urls );
-	bool stat = false;
+   if( url.isMalformed() ) 
+   {
+      message( i18n("Malformed URL.") );
+   }
+   else if( url.isLocalFile() ) 
+   {
+      stat = _canvas->save( url.path() );
+   }
+   else 
+   {
+      message( i18n("Net saving not yet implemented") );
+   }
 
-	if( url.isMalformed() ) {
-		stat = _canvas->save( urls );
-	}
-	else if( url.isLocalFile() ) {
-		stat = _canvas->save( url.path() );
-	}
-	else {
-		message( i18n("Net saving not yet implemented") );
-	}
+   if( stat == false ) 
+      return;
 
-	if( stat == false ) {
-		return;
-	}
-
-	QString msg = urls;
-	ksprintf( &msg, i18n( "%s: written" ), urls.data() );
-	message( msg );
+   message( i18n("%1: written").arg(url.prettyURL()) );
 }
 
 void KImageViewer::zoomIn10()
 {
-	_mat.scale( 1.1, 1.1 );
+   _mat.scale( 1.1, 1.1 );
 
-	_canvas->transformImage( _mat );
+   _canvas->transformImage( _mat );
 }
 
 void KImageViewer::zoomOut10()
 {
-	_mat.scale( 0.9, 0.9 );
+   _mat.scale( 0.9, 0.9 );
 
-	_canvas->transformImage( _mat );
+   _canvas->transformImage( _mat );
 }
 
 void KImageViewer::zoomIn200()
 {
-	_mat.scale( 2.0, 2.0 );
+   _mat.scale( 2.0, 2.0 );
 
-	_canvas->transformImage( _mat );
+   _canvas->transformImage( _mat );
 }
 
 void KImageViewer::zoomOut50()
 {
-	_mat.scale( 0.5, 0.5 );
+   _mat.scale( 0.5, 0.5 );
 
-	_canvas->transformImage( _mat );
+   _canvas->transformImage( _mat );
 }
 
 void KImageViewer::zoomCustom()
 {
-	KNumDialog num;
-	_zoomFactor = (int)(_mat.m11() * 100);
+   KNumDialog num;
+   _zoomFactor = (int)(_mat.m11() * 100);
 
-	if( !num.getNum( _zoomFactor, i18n(
-			"Enter Zoom factor (100 = 1x):" ) ) )
-		return;
+   if( !num.getNum( _zoomFactor, i18n("Enter Zoom factor (100 = 1x):") ) )
+      return;
 
-	if( _zoomFactor <= 0 ) {
-		message( i18n( "Illegal zoom factor" ) );
-		return;
-	}
+   if( _zoomFactor <= 0 ) 
+   {
+      message( i18n( "Illegal zoom factor" ) );
+      return;
+   }
 		
-	double val = (double)_zoomFactor/100;
-	_mat.reset();
-	_mat.scale( val, val );
-	_canvas->transformImage( _mat );
+   double val = (double)_zoomFactor/100;
+   _mat.reset();
+   _mat.scale( val, val );
+   _canvas->transformImage( _mat );
 }
 
 void KImageViewer::rotateClock()
 {
-	_mat.rotate( 90 );
+   _mat.rotate( 90 );
 
-	_canvas->transformImage( _mat );
+   _canvas->transformImage( _mat );
 }
 
 void KImageViewer::rotateAntiClock()
 {
-	_mat.rotate( -90 );
+   _mat.rotate( -90 );
 
-	_canvas->transformImage( _mat );
+   _canvas->transformImage( _mat );
 }
 
 void KImageViewer::flipVertical()
 {
-	QWMatrix m( 1.0F, 0.0F, 0.0F, -1.0F, 0.0F, 0.0F );
+   QWMatrix m( 1.0F, 0.0F, 0.0F, -1.0F, 0.0F, 0.0F );
 
-	_mat *= m;
+   _mat *= m;
 
-	_canvas->transformImage( _mat );
+   _canvas->transformImage( _mat );
 }
 
 void KImageViewer::flipHorizontal()
 {
-	QWMatrix m( -1.0F, 0.0F, 0.0F, 1.0F, 0.0F, 0.0F );
+   QWMatrix m( -1.0F, 0.0F, 0.0F, 1.0F, 0.0F, 0.0F );
 
-	_mat *= m;
+   _mat *= m;
 
-	_canvas->transformImage( _mat );
+   _canvas->transformImage( _mat );
 }
 
 void KImageViewer::help()
 {
-	kapp->invokeHTMLHelp( "kview/kview.html", "" );	
+   kapp->invokeHelp( );	
 }
 
 void KImageViewer::about()
 {
-	QString aboutText;
-	
-	aboutText.sprintf( i18n( "KView -- Graphics viewer. %s\n"
-		"\nSirtaj S. Kang (taj@kde.org)\n" ), KVIEW_VERSION );
+   QString aboutText = i18n( "KView -- Graphics viewer. %1\n"
+              "\nSirtaj S. Kang (taj@kde.org)\n" ).arg( KVIEW_VERSION );
 
-	QMessageBox::about( this, i18n("About KView"), aboutText );
+   KMessageBox::about(this, aboutText, i18n("About KView"));
 }
 
 void KImageViewer::makeRootMenu(QPopupMenu *menu)
@@ -348,14 +334,14 @@ void KImageViewer::makePopupMenus()
 	// file pulldown
 
 	_watcher->setMenu( _file );
-	conn( i18n( "&Open..." ), KAccel::Open, this, SLOT(load()) );
-	conn( i18n( "&Save As..." ), KAccel::Save, this, SLOT(saveAs()) );
-	conn( i18n( "&Print..." ), KAccel::Print, this, SLOT(printImage()));
+	conn( i18n( "&Open..." ), KStdAccel::Open, this, SLOT(load()) );
+	conn( i18n( "&Save As..." ), KStdAccel::Save, this, SLOT(saveAs()) );
+	conn( i18n( "&Print..." ), KStdAccel::Print, this, SLOT(printImage()));
 	_file->insertSeparator();
-	conn( i18n( "&New Window" ), KAccel::New, this, SLOT(newViewer()));
-	conn( i18n( "&Close Window" ),KAccel::Close, this, SLOT(closeViewer()));
+	conn( i18n( "&New Window" ), KStdAccel::New, this, SLOT(newViewer()));
+	conn( i18n( "&Close Window" ),KStdAccel::Close, this, SLOT(closeViewer()));
 	_file->insertSeparator();
-	conn( i18n( "E&xit" ), KAccel::Quit, this, SLOT(quitApp()) );
+	conn( i18n( "E&xit" ), KStdAccel::Quit, this, SLOT(quitApp()) );
 
 	// edit pulldown
 	_watcher->setMenu( _edit );
@@ -418,11 +404,11 @@ void KImageViewer::makePopupMenus()
 	conn( i18n("&Next"), "Next", _imageList, SLOT(next()),
 			Key_Tab );
 	_aggreg->insertSeparator();
-	_aggreg->insertItem( i18n("&Slideshow On/Off"), "Slideshow", 
+	_aggreg->insertItem( i18n("&Slideshow On/Off"), 
 		_imageList, SLOT(toggleSlideShow()), Key_S );
 
 	_watcher->setMenu( _help );
-	conn( i18n( "&Contents" ), KAccel::Help, this, SLOT(help()));
+	conn( i18n( "&Contents" ), KStdAccel::Help, this, SLOT(help()));
 	conn( i18n( "&How do I..." ), "HelpHow", this, SLOT(helpHow()));
 	conn( i18n( "&What is a..." ), "HelpWhat", this, SLOT(helpWhat()));
 	_help->insertSeparator();
@@ -431,7 +417,7 @@ void KImageViewer::makePopupMenus()
 
 void KImageViewer::quitApp()
 {
-	KApplication::getKApplication()->quit();
+	KApplication::kApplication()->quit();
 }
 
 void KImageViewer::tile()
@@ -449,95 +435,23 @@ void KImageViewer::maxpect()
 	_canvas->maxpectToDesktop();
 }
 
-void KImageViewer::loadURL( const char *url )
+void KImageViewer::loadURL( const KURL &url )
 {
-	if( url == 0 ) {
-		warning( "loadURL: called with null url" );
-		return;
-	}
+   if( url.isMalformed() ) {
+      warning( "loadURL: called with invalid url" );
+      return;
+   }
 
-	KURL kurl( url );
-
-	if( kurl.isMalformed() ) {
-		loadFile( url );
-	}
-	else if( kurl.isLocalFile() ) {
-		// local file - open with loadFile
-		loadFile( kurl.path(), url );
-	}
-	else {
-		// connect to kfm
-		if( _kfm != 0 ) {
-			message( i18n( "Existing transfer not yet complete."));
-			return;
-		}
-
-		_kfm = new KFM;
-
-		if( !_kfm || !_kfm->isKFMRunning() || !_kfm->isOK() ) {
-			message( i18n( "Existing transfer not yet complete."));
-			return;
-		}
-
-		// save transfer files
-		if( _transSrc == 0 )
-			_transSrc = new QString;
-		if( _transDest == 0 )
-			_transDest = new QString;
-
-		_transSrc->setStr( url );
-		_transDest->setStr( tempnam( 0, "kview_") );
-
-		if( _transSrc->isEmpty() || _transDest->isEmpty() ) {
-			message( 
-			i18n( "Couldn't get temporary transfer name." ) );
-			return;
-		}
-
-		// start transfer
-		connect( _kfm, SIGNAL( finished() ),
-			this, SLOT( urlFetchDone() ) );
-		connect( _kfm, SIGNAL( error(int, const char *) ),
-			this, SLOT( urlFetchError(int, const char *) ) );
-
-		_kfm->copy( _transSrc->data(), _transDest->data() );
-		_transDir = Get;
-	}
+   QString tmpfile;
+   if ( KIO::NetAccess::download( url, tmpfile) )
+     loadFile( tmpfile, url );
+   else
+     KMessageBox::error( this, i18n("Could not load\n%1").arg(url.prettyURL()) );
 }
 
-void KImageViewer::urlFetchDone()
+void KImageViewer::appendURL( const KURL &url, bool show )
 {
-	if( _kfm == 0 ) {
-		warning( "KImageViewer: urlFetchDone() called but no transfer in progress." );
-		return;
-	}
-
-	switch ( _transDir ) {
-		case Get:	loadFile( _transDest->data(),
-				_transSrc->data() );
-				unlink( _transDest->data() );
-				break;
-		case Put:	break;
-	}
-
-	delete _kfm;
-	_kfm = 0;
-}
-
-void KImageViewer::urlFetchError( int,  const char *text )
-{
-	delete _kfm;
-	_kfm = 0;
-
-	QString msg( i18n("Transfer error: ") );
-	msg += text;
-
-	message( msg );
-}
-
-void KImageViewer::appendURL( const char *url, bool show )
-{
-	_imageList->addURL( url, show );
+   _imageList->addURL( url, show );
 }
 
 void KImageViewer::invokeFilter( KImageFilter *f )
@@ -567,10 +481,10 @@ void KImageViewer::setFilterMenu( KFiltMenuFactory *filtmenu )
 				_canvas, SLOT(setImage(const QImage&)) );
 		connect( filter, SIGNAL(progress(int)),
 			this, SLOT(setProgress(int)) );
-		connect( filter, SIGNAL(status(const char *)),
-			this, SLOT(setStatus(const char *)) );
-		connect( filter, SIGNAL(message(const char *)),
-			this, SLOT(message(const char *)) );
+		connect( filter, SIGNAL(status(const QString &)),
+			this, SLOT(setStatus(const QString &)) );
+		connect( filter, SIGNAL(message(const QString &)),
+			this, SLOT(message(const QString &)) );
 	}
 
 	_menuFact = filtmenu;
@@ -593,84 +507,81 @@ void KImageViewer::setFilterMenu( KFiltMenuFactory *filtmenu )
 	_watcher->updateMenus();
 }
 
-void KImageViewer::setStatus( const char *status )
+void KImageViewer::setStatus( const QString & status )
 {
-	if ( status == 0 ) {
-		status = i18n( "Ready" );
-	}
-
-	_statusbar->changeItem( status, StatStatus );
+	if ( status.isEmpty() ) 
+		_statusbar->changeItem( i18n( "Ready" ), StatStatus );
+	else
+		_statusbar->changeItem( status, StatStatus );
 }
 
-void KImageViewer::loadFile( const char *file, const char *url )
+void KImageViewer::loadFile( QString file, const KURL &_url )
 {
-	if( url == 0 ) {
-		url = file;
-	}
+   KURL url(_url);
+   if( url.isEmpty() ) 
+   {
+      url = file;
+   }
 
-	// We need to do this, in case the image takes too long to load.
-	bool slide = _imageList->slideShowRunning();
+   // We need to do this, in case the image takes too long to load.
+   bool slide = _imageList->slideShowRunning();
 
-	if( slide ) {
-		_imageList->pauseSlideShow();
-	}
+   if( slide ) 
+   {
+      _imageList->pauseSlideShow();
+   }
 
-	setStatus( i18n( "Loading..." ) );
+   setStatus( i18n( "Loading..." ) );
 
-	// load the image
-	_canvas->load( file, 0, _loadMode == ResizeImage );
+   // load the image
+   _canvas->load( file, 0, _loadMode == ResizeImage );
 
+   // update state
+   setStatus( 0 );
 
+   if( _canvas->status() != KImageCanvas::OK ) 
+   {
+      message( i18n("Couldn't load %1").arg(url.prettyURL()) );
+   }
+   else 
+   {
+      // resize window to screen
+      if( _loadMode == ResizeWindow && _statusbar->isVisible() ) 
+      {
+         rzWinToImg();	
+      }
 
-	// update state
+      // set caption
+      setCaption( url.prettyURL() );
 
-	setStatus( 0 );
+      // enable filters
+      if( !_imageLoaded ) 
+      {
+         _menubar->setItemEnabled( _barFilterID, true );
+         _contextMenu->setItemEnabled( _popFilterID, true );
+         _imageLoaded = true;
+      }
+      // reset matrix
+      _mat.reset();
+   }
 
-	if( _canvas->status() != KImageCanvas::OK ) {
-
-		QString msg;
-		msg.sprintf(i18n("Couldn't load %s"), url);
-		message( msg );
-	}
-	else {
-		// resize window to screen
-		if( _loadMode == ResizeWindow && _statusbar->isVisible() ) {
-			rzWinToImg();	
-		}
-
-		// set caption
-		QString cap = url;
-		cap += " (";
-		cap += kapp->appName().data();
-		cap += ")";
-		setCaption( cap );
-
-		// enable filters
-		if( !_imageLoaded ) {
-			_menubar->setItemEnabled( _barFilterID, true );
-			_contextMenu->setItemEnabled( _popFilterID, true );
-			_imageLoaded = true;
-		}
-		// reset matrix
-		_mat.reset();
-	}
-
-	if ( slide ) {
-		_imageList->continueSlideShow();
-	}
+   if ( slide ) 
+   {
+      _imageList->continueSlideShow();
+   }
 }
 
 void KImageViewer::setSize()
 {
-		// size
-		QWidget *desk = kapp->desktop();
+   // size
+   QWidget *desk = kapp->desktop();
 
-		if( _canvas->height() < desk->height()
-			&& _canvas->width() < desk->width()
-			&& _canvas->height() ) {
-
-			resize( _canvas->size() );
-		}
+   if( _canvas->height() < desk->height()
+   	&& _canvas->width() < desk->width()
+   	&& _canvas->height() ) 
+   {
+      resize( _canvas->size() );
+   }
 }
 
 void KImageViewer::setProgress( int pct )
@@ -691,7 +602,7 @@ void KImageViewer::setProgress( int pct )
 	_statusbar->changeItem( buf, StatProgress );
 }
 
-void KImageViewer::message( const char *message )
+void KImageViewer::message( const QString &message )
 {
 	_statusbar->message( message, MessageDelay );
 
@@ -889,7 +800,7 @@ void KImageViewer::paste()
 
 void KImageViewer::prefs()
 {
-	KConfig *cfg = kapp->getConfig();
+	KConfig *cfg = kapp->config();
 	KViewPrefDlg dlg( cfg, _kaccel );
 
 	saveOptions( cfg );
@@ -969,7 +880,7 @@ int KImageViewer::conn( const char *text, const char *action,
 	return id;
 }
 
-int KImageViewer::conn( const char *text, KAccel::StdAccel action,
+int KImageViewer::conn( const char *text, KStdAccel::StdAccel action,
 	QObject *receiver, const char *method )
 {
 	QPopupMenu *menu = _watcher->currentMenu();
@@ -1001,6 +912,7 @@ plan: to make the client area of the KTW == area of canvas contents.
 */
 	int iw = _canvas->contentsWidth();
 	int ih = _canvas->contentsHeight();
+
 	QRect geom = frameGeometry();
 	QRect desk = kapp->desktop()->geometry();
 
@@ -1011,6 +923,9 @@ plan: to make the client area of the KTW == area of canvas contents.
 	int ymax = desk.height() - ( yextra + geom.y() );
 
 	setGeometry( geom.x(), geom.y(), 
-		QMIN( iw, xmax ) + xextra, 
-		QMIN( ih, ymax ) + yextra );
+		     QMIN( iw, xmax ) + xextra, 
+		     QMIN( ih, ymax ) + yextra );
 }
+
+#include "viewer.moc"
+
